
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class RolePowerModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(RolePowerModel, self).__init__(RolePower, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class RolePower:

    def __init__(self):
        super(RolePower, self).__init__()
        self.RolePowerID = 0  # 权限标识
        self.RoleID = ""  # 角色标识
        self.MenuID = ""  # 菜单标识
        self.CoteID = ""  # 数据ID

    @classmethod
    def get_field_list(self):
        return ['RolePowerID', 'RoleID', 'MenuID', 'CoteID']
        
    @classmethod
    def get_primary_key(self):
        return "RolePowerID"

    def __str__(self):
        return "cms_rolepower_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-12-09 19:11:51
:LastEditTime: 2023-04-28 13:36:44
:LastEditors: HuangJingCan
:Description: 
"""

from seven_studio.handlers.studio_base import *
from seven_studio.models.db_models.settings.settings_base_model import *


class BaseSettingsHandler(StudioBaseHandler):
    @login_filter(True)
    def post_async(self):
        """
        :description: 设置站点基础信息
        :return 基础信息
        :last_editors: ChenXiaolei
        """
        # 登录页背景图
        login_background = self.get_param("login_background")
        # 登录页logo
        login_logo = self.get_param("login_logo")
        # 首页顶部logo
        banner_logo = self.get_param("banner_logo")
        # 标题
        title = self.get_param("title")
        # 登录过期时间(小时)
        login_expire = int(self.get_param("login_expire", 2))

        settings_base_model = SettingsBaseModel(config.get_value("manage_context_key", "db_sevenstudio"))

        settings_base = settings_base_model.get_entity()

        if not settings_base:
            settings_base = SettingsBase()

        settings_base.login_background = login_background
        settings_base.login_logo = login_logo
        settings_base.banner_logo = banner_logo
        settings_base.title = title
        settings_base.login_expire = login_expire

        if settings_base.id > 0:
            settings_base_model.update_entity(settings_base)
        else:
            settings_base_model.add_entity(settings_base)

        if config.get_value("login_type", "redis") == "redis":
            redis_init = self.redis_init()
            settings_base = redis_init.delete("settings_base")

        return self.response_json_success(settings_base)

    def get_async(self):
        """
        :description: 获取站点基础信息
        :return 基础信息
        :last_editors: ChenXiaolei
        """
        settings_base_model = SettingsBaseModel(config.get_value("manage_context_key", "db_sevenstudio"))

        settings_base = None
        if config.get_value("login_type", "redis") == "redis":
            redis_init = self.redis_init()
            settings_base = redis_init.get("settings_base")
            if not settings_base:
                settings_base = settings_base_model.get_dict()
                redis_init.set("settings_base", self.json_dumps(settings_base))
            else:
                settings_base = self.json_loads(settings_base)
        else:
            settings_base = settings_base_model.get_dict()

        return self.response_json_success(settings_base)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2020-12-09 10:27:49
:LastEditors: ChenXiaolei
:Description: 用户信息扩展类
"""

from seven_studio.models.db_models.user.user_info_model import *
from seven_framework.crypto import *


class UserInfoModelEx(UserInfoModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super().__init__(db_connect_key=db_connect_key, sub_table=sub_table)

    def sign_password(self, login_password="", userid=""):
        if login_password.strip() == '':
            return CryptoHelper.md5_encrypt(config.get_value("default_password", "7777777"), userid)
        return CryptoHelper.md5_encrypt(login_password, userid).upper()

    def verify_password(self, login_password="", password="", userid=""):
        return password.upper() == CryptoHelper.md5_encrypt(login_password, userid).upper()

    def is_force_password(self, user_info):
        if user_info:
            return self.verify_password(config.get_value("default_password", "7777777"), user_info.Password, user_info.UserID)
        return False



# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2023-04-28 11:44:06
:LastEditors: HuangJingCan
:Description: 产品相关Handler
"""

from seven_studio.handlers.studio_base import *
from seven_studio.models.db_models.product.product_info_model import *
from seven_studio.models.db_models.product.product_user_model import *


class GetProductListHandler(StudioBaseHandler):
    """
    :description: 产品列表
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 产品列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 数据库连接串
        product_info_model = ProductInfoModel(config.get_value("base_manage_context_key", "db_sevenstudio"))
        # 页索引
        page_index = self.get_page_index()
        # 页大小
        page_size = self.get_page_size()
        # 查询条件,排序字段
        condition, order = self.get_condition_by_body()

        source_dict_list = product_info_model.get_dict_list(condition, "", order)
        if len(source_dict_list) > 0:
            merge_dict_list = UserInfoModel(self.get_manage_context_key()).get_dict_list(field="UserID,UserName")
            source_dict_list = DictUtil.merge_dict_list(source_dict_list, "SuperID", merge_dict_list, "UserID", "UserID,UserName")
        page_dict = self.get_dict_page_info_list(page_index, page_size, source_dict_list)

        return self.response_json_success(page_dict)


class GetAllProductListHandler(StudioBaseHandler):
    """
    :description: 全部产品列表
    """
    @login_filter(True)
    def get_async(self):
        """
        :description: 全部产品列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        product_info_model = ProductInfoModel(config.get_value("base_manage_context_key", "db_sevenstudio"))
        source_dict_list = product_info_model.get_dict_list()

        return self.response_json_success(source_dict_list)


class SaveProductHandler(StudioBaseHandler):
    """
    :description: 保存产品
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 保存产品
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 数据库连接串
        base_manage_context_key = config.get_value("base_manage_context_key", "db_sevenstudio")
        # 产品id
        product_id = int(self.get_param("ProductID", "0"))
        # 产品名称
        product_name = self.get_param("ProductName")
        # 产品子名称
        product_sub_name = self.get_param("ProductSubName")
        # 业务地址
        manage_url = self.get_param("ManageUrl")
        # 权限地址
        power_url = self.get_param("PowerUrl")
        # 说明
        summary = self.get_param("Summary")
        # 图片地址
        image_url = self.get_param("ImageUrl")
        # 超管ID
        super_id = self.get_param("SuperID")
        # 文件上下文配置
        file_context_key = self.get_param("FileContextKey")
        # 权限上下文配置
        manage_context_key = self.get_param("ManageContextKey")
        # 日志上下文配置
        log_context_key = self.get_param("LogContextKey")
        # 作业上下文配置
        plug_work_context_key = self.get_param("PlugWorkContextKey")
        # 是否发布
        is_release = int(self.get_param("IsRelease", "0"))
        # 是否新页面打开
        is_brank = int(self.get_param("IsBrank", "0"))

        # 验证数据
        if product_name == "":
            return self.response_common("ProductNameEmpty", "产品名称为空")

        if not config.get_value(manage_context_key):
            return self.response_common("HasExit", "ManageContentKey链接字符串未配置")

        product_info_model = ProductInfoModel(base_manage_context_key)
        product_info = ProductInfo()
        if product_id > 0:
            product_info = product_info_model.get_entity_by_id(product_id)
            if not product_info:
                return self.response_common("NoExit", "产品不存在")
            if manage_url != "" or power_url != "":
                product_info_c = product_info_model.get_entity("(ManageUrl=%s OR PowerUrl=%s) AND ProductID<>%s", params=[manage_url, power_url, product_id])
                if product_info_c:
                    return self.response_common("HasExit", "WebUrl或ApiUrl已存在")
        elif manage_url != "" or power_url != "":
            product_info_c = product_info_model.get_entity("ManageUrl=%s OR PowerUrl=%s", params=[manage_url, power_url])
            if product_info_c:
                return self.response_common("HasExit", "WebUrl或ApiUrl已存在")

        # 赋值
        product_info.ProductName = product_name
        product_info.ProductSubName = product_sub_name
        product_info.ManageUrl = manage_url
        product_info.PowerUrl = power_url
        product_info.Summary = summary
        product_info.ImageUrl = image_url
        product_info.SuperID = super_id
        product_info.Summary = summary
        product_info.FileContextKey = file_context_key
        product_info.ManageContextKey = manage_context_key
        product_info.LogContextKey = log_context_key
        product_info.PlugWorkContextKey = plug_work_context_key
        product_info.IsRelease = is_release
        product_info.IsBrank = is_brank
        if product_id > 0:
            product_info_model.update_entity(product_info)
        else:
            product_id = product_info_model.add_entity(product_info)
            product_info.ProductID = product_id

        user_info_model = UserInfoModel(manage_context_key)

        user_info_model.update_table("IsSuper=0", "Account<>'seven'")
        user_info_model.update_table("IsSuper=1", "UserID=%s", params=[super_id])

        return self.response_json_success(product_info)


class DeleteProductHandler(StudioBaseHandler):
    """
    :description: 删除产品
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除产品
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        product_id = int(self.get_param("ProductID", 0))

        if product_id <= 0:
            return self.response_json_error_params()

        product_info_model = ProductInfoModel(config.get_value("base_manage_context_key", "db_sevenstudio"))

        product_info_model.del_entity("ProductID=%s", product_id)

        return self.response_json_success()


"""
:Author: dongyu
:Date: 2020-04-11 18:44:08
:LastEditTime: 2023-04-28 13:51:41
:LastEditors: HuangJingCan
:Description: 菜单相关类
"""
from seven_studio.handlers.studio_base import *
from seven_studio.models.db_models.menu.menu_cote_model import *
from seven_studio.models.db_models.menu.menu_info_model_ex import *
from seven_studio.models.power_model import *


class PowerPlatformMenuHandler(StudioBaseHandler):
    """
    :description: 权限的栏目菜单路由
    """
    @login_filter(True)
    @power_filter(False)
    def get_async(self):
        """
        :description: 根据登陆用户获取用户有权限的栏目菜单
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 数据库连接串
        manage_context_key = self.get_manage_context_key()
        # 是否超管
        is_super = self.get_is_super()
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 产品id
        product_id = self.request_product_id()

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        result = power_model.get_platform_power_menu_list()

        return self.response_json_success(result)


class PowerMenuTreeHandler(StudioBaseHandler):
    """
    :description: 菜单权限路由
    """
    @login_filter(True)
    @power_filter(False)
    def get_async(self):
        """
        :description: 获取权限树
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        manage_context_key = self.get_manage_context_key()
        is_super = self.get_is_super()
        curr_user_id = self.request_user_id()
        product_id = self.request_product_id()
        # 是否权限无限下放（0-无限等级，1-下放一级）
        power_grade = int(config.get_value("power_grade", 1))

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        result = power_model.get_menu_item_tree()

        # 非超管则无权限下放功能，没有用户和角色添加权限
        if not is_super and power_grade > 0:
            result = [i for i in result if i['MenuID'] != config.get_value("menu_id_platform", "03E5D2A0-DB59-47F6-8F10-1ACDEFE9BDDD")]

        return self.response_json_success(result)


class MenuTreeHandler(StudioBaseHandler):
    """
    :description: 系统菜单路由
    """
    @login_filter(True)
    def get_async(self):
        """
        :description: 获取系统菜单树
        :param {type} 
        :return: 列表
        """
        manage_context_key = self.get_manage_context_key()
        curr_user_id = self.request_user_id()
        product_id = self.request_product_id()

        power_model = PowerModel(manage_context_key, True, curr_user_id, product_id)
        result = power_model.get_menu_item_tree(False)

        return self.response_json_success(result)


class MenuPowerInfoHandler(StudioBaseHandler):
    """
    :description: 栏目权限路由
    """
    def get_async(self):
        """
        :description: 栏目权限信息路由，用于获取栏目的角色和用户信息
        :param {type} 
        :return: 列表
        :last_editors: HuangJingCan
        """
        manage_context_key = self.get_manage_context_key()
        is_super = self.get_is_super()
        curr_user_id = self.request_user_id()
        product_id = self.request_product_id()

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        result = power_model.get_power_menu_role_list(self.get_param("menuID"))

        return self.response_json_success(result)


class MenuCoteListHandler(StudioBaseHandler):
    """
    :description: 栏目数据路由
    """
    def post_async(self):
        """
        :description: 获取栏目数据列表
        :param {type} 
        :return: 列表
        :last_editors: HuangJingCan
        """
        page_index = self.get_page_index()
        page_size = self.get_page_size()
        condition, order = self.get_condition_by_body()

        p_dict, total = MenuCoteModel(self.get_manage_context_key()).get_dict_page_list("*", page_index, page_size, condition, "", order)

        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))


class MenuCoteSelectHandler(StudioBaseHandler):
    """
    :description: MenuCoteSelectHandler
    """
    def get_async(self):
        """
        :description: GetMenuCoteSelect
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        p_dict = MenuCoteModel(self.get_manage_context_key()).get_dict_list(field="MenuCoteID,CoteTitle")

        return self.response_json_success(p_dict)


class SaveMenuHandler(StudioBaseHandler):
    """
    :description: 保存菜单
    """
    def post_async(self):
        """
        :description: 保存菜单
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 菜单标识
        menu_id = self.get_param("id")
        # 父标识
        parent_id = self.get_param("parentID")
        # 菜单类型
        menu_type = self.get_param("menuType")
        # 图标地址
        menu_icon = self.get_param("menuIcon")
        # 菜单名称
        menu_name = self.get_param("menuName")
        # 是否显示0不显示1显示
        is_show = int(self.get_param("isShow", "0"))
        # 是否授权0不1是
        is_power = int(self.get_param("isPower", "0"))
        # 接口地址
        api_path = self.get_param("apiPath")
        # 视图地址
        view_path = self.get_param("viewPath")
        # 跳转地址
        target_url = self.get_param("targetUrl")
        # 菜单命令
        command_name = self.get_param("commandName")
        # 菜单参数
        command_parms = self.get_param("commandParms")
        # 1顶部2列表3底部
        button_place = self.get_param("buttonPlace")
        # 按钮颜色
        button_color = self.get_param("buttonColor")
        # 菜单显示条件
        show_condition_str = self.get_param("showConditionStr")
        # 栏目数据ID
        menu_cote_id = int(self.get_param("menuCoteID", "0"))
        # 栏目标识
        menu_cote_key = self.get_param("menuCoteKey")
        # 排序号
        sort_index = int(self.get_param("sortIndex", "0"))
        old_menu_name = ""

        # 验证数据
        if menu_name == "":
            return self.response_common("MenuNameEmpty", "菜单名为空")
        if [1, 2, 3].__contains__(menu_type):
            return self.response_common("MenuTypeError", "菜单类型错误")
        menu_info_model_ex = MenuInfoModelEx(self.get_manage_context_key())
        if menu_id != "":
            menu_info = menu_info_model_ex.get_entity_by_id(menu_id)
            if not menu_info:
                return self.response_common("NoExit", "菜单不存在")
            old_menu_name = menu_info.MenuName
        else:
            menu_info = MenuInfo()

        # 赋值保存
        menu_info.ParentID = parent_id
        menu_info.MenuType = menu_type
        menu_info.MenuIcon = menu_icon
        menu_info.MenuName = menu_name
        menu_info.IsShow = is_show
        menu_info.ApiPath = api_path
        menu_info.ViewPath = view_path
        menu_info.TargetUrl = target_url
        menu_info.IsPower = is_power
        menu_info.CommandName = command_name
        menu_info.CommandParms = command_parms
        menu_info.ButtonPlace = button_place
        menu_info.ButtonColor = button_color
        menu_info.ShowCondition = show_condition_str
        menu_info.MenuCoteID = menu_cote_id
        menu_info.MenuCoteKey = menu_cote_key
        menu_info.SortIndex = sort_index

        if menu_id == "":
            menu_info_model_ex.add_menu(menu_info)
        else:
            menu_info_model_ex.update_menu(menu_info)

        if old_menu_name and old_menu_name != menu_name:
            menu_info_model_ex.update_table(f"MenuNamePath=REPLACE(MenuNamePath,',{old_menu_name},',',{menu_name},')", f"IDPath LIKE '%{menu_id}%'")

        return self.response_json_success(menu_info)


class AddFastMenuHandler(StudioBaseHandler):
    """
    :description: 快速添加菜单
    """
    def get_async(self):
        """
        :description: 快速添加菜单-保存
        :return: 菜单id
        :last_editors: HuangJingCan
        """
        # 父栏目id
        parent_id = self.get_param("parentID")
        # 按钮类型
        button_type_str = self.get_param("buttonTypeStr")
        # 按钮名称后缀
        suffix_name = self.get_param("suffixName")

        if parent_id == "":
            return self.response_common("ParentIDEmpty", "父节点为空")
        if button_type_str == "":
            return self.response_common("ButtonTypeEmpty", "菜单类型为空")

        MenuInfoModelEx(self.get_manage_context_key()).add_fast_menu(parent_id, suffix_name, button_type_str)

        return self.response_json_success()


class DeleteMenuHandler(StudioBaseHandler):
    """
    :description: 删除菜单
    """
    def get_async(self):
        """
        :description: 删除菜单
        :param id：菜单id
        :return: 
        :last_editors: HuangJingCan
        """
        menu_id = self.get_param("id")
        if menu_id == "":
            return self.response_common("MenuIDEmpty", "菜单ID为空")

        MenuInfoModelEx(self.get_manage_context_key()).delete(menu_id)

        return self.response_json_success()


class SaveCopyMenuHandler(StudioBaseHandler):
    """
    :description: 复制粘贴菜单
    """
    def get_async(self):
        """
        :description: 复制粘贴菜单
        :param copyMenuID：复制的菜单id
        :param stickMenuID：粘贴的菜单id
        :return: 
        :last_editors: HuangJingCan
        """
        # 复制的菜单id
        copy_menu_id = self.get_param("copyMenuID")
        # 粘贴的菜单id
        stick_menu_id = self.get_param("stickMenuID")
        if copy_menu_id == "":
            return self.response_common("SaveCopyMenuHandler", "操作失败，复制节点为空")
        if stick_menu_id == "":
            return self.response_common("SaveCopyMenuHandler", "操作失败，粘贴节点为空")
        if copy_menu_id == stick_menu_id:
            return self.response_common("SaveCopyMenuHandler", "操作失败，无法粘贴到自身节点下")

        invoke_result = MenuInfoModelEx(self.get_manage_context_key()).add_copy_menu(copy_menu_id, stick_menu_id)
        if invoke_result.ResultCode != "0":
            return self.response_common("SaveCopyMenuHandler", invoke_result.ResultMessage)

        return self.response_json_success()


class MoveMenuHandler(StudioBaseHandler):
    """
    :description: 移动菜单
    """
    def get_async(self):
        """
        :description: 移动菜单
        :param id：被移动的菜单id
        :param targetId：目的地菜单id
        :param moveType：移动类型
        :return: 
        :last_editors: HuangJingCan
        """
        # 目的地菜单id
        target_id = self.get_param("targetId")
        # 移动类型
        move_type = self.get_param("moveType")
        # 被移动的菜单id
        menu_id = self.get_param("id")
        if menu_id == "":
            return self.response_common("MenuIDEmpty", "菜单ID为空")

        menu_info_model_ex = MenuInfoModelEx(self.get_manage_context_key())
        menu_info = menu_info_model_ex.get_entity_by_id(menu_id)

        if not menu_info:
            return self.response_common("NoExit", "菜单不存在")

        menu_info = menu_info_model_ex.get_entity_by_id(target_id)
        if menu_info and menu_info.MenuType == 1:
            return self.response_common("MoveMenuHandler", "移动失败，请勿移动到最外层")
        if menu_info and menu_info.MenuType == 3:
            return self.response_common("MoveMenuHandler", "移动失败，请勿移动到操作菜单下")

        if move_type == "inner":
            menu_info_model_ex.update_move(menu_id, target_id)
        elif move_type == "after":
            menu_info_model_ex.update_after_before_move(menu_id, target_id, "SortIndex", f"ParentID='{menu_info.ParentID}'")
        else:
            menu_info_model_ex.update_after_before_move(menu_id, target_id, "SortIndex", f"ParentID='{menu_info.ParentID}'", False)

        return self.response_json_success()


class SaveMenuCoteHandler(StudioBaseHandler):
    """
    :description: 修改栏目数据
    """
    def post_async(self):
        """
        :description: 保存栏目数据
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 栏目数据id
        menu_cote_id = int(self.get_param("MenuCoteID", "0"))
        # 栏目名称
        cote_title = self.get_param("CoteTitle")
        # 栏目表名
        cote_table_name = self.get_param("CoteTableName")
        # 主键名
        id_name = self.get_param("IDName")
        # 显示名称
        name = self.get_param("Name")
        # 父节点标识
        parent_id_name = self.get_param("ParentIDName")
        # ID路经名称
        id_path_name = self.get_param("IDPathName")
        # 链接字符串
        connection_string_name = self.get_param("ConnectionStringName")
        # 根节点ID值
        root_id_value = self.get_param("RootIDValue")
        # ID类型1整型2字符串
        id_data_type = int(self.get_param("IDDataType", "0"))
        # 排序
        sort_Expression = self.get_param("SortExpression")
        # 条件
        condtion = self.get_param("Condtion")
        # 是否父节点链接
        is_paren_url = int(self.get_param("IsParentUrl", "0"))

        menu_cote_model = MenuCoteModel(self.get_manage_context_key())
        menu_cote = MenuCote()
        if menu_cote_id > 0:
            menu_cote = menu_cote_model.get_entity_by_id(menu_cote_id)
            if not menu_cote:
                return self.response_common("NoExit", "数据不存在")

        menu_cote.CoteTitle = cote_title
        menu_cote.CoteTableName = cote_table_name
        menu_cote.IDName = id_name
        menu_cote.Name = name
        menu_cote.ParentIDName = parent_id_name
        menu_cote.IDPathName = id_path_name
        menu_cote.ConnectionStringName = connection_string_name
        menu_cote.RootIDValue = root_id_value
        menu_cote.IDDataType = id_data_type
        menu_cote.SortExpression = sort_Expression
        menu_cote.Condtion = condtion
        menu_cote.IsParentUrl = is_paren_url

        if menu_cote.MenuCoteID > 0:
            menu_cote_model.update_entity(menu_cote)
        else:
            menu_cote_model.add_entity(menu_cote)

        return self.response_json_success(menu_cote)


class DeleteMenuCoteHandler(StudioBaseHandler):
    """
    :description: 删除栏目数据
    """
    def get_async(self):
        """
        :description: 删除栏目数据
        :param id：栏目数据id
        :return: 
        :last_editors: HuangJingCan
        """
        menu_cote_id = self.get_param("MenuCoteID")
        if menu_cote_id == "":
            return self.response_common("MenuCoteIDEmpty", "栏目数据ID为空")

        MenuCoteModel(self.get_manage_context_key()).del_entity("MenuCoteID=%s", menu_cote_id)

        return self.response_json_success()


class SyncSqlHandler(StudioBaseHandler):
    """
    :description: sql同步语句导出
    """
    def get_async(self):
        """
        :description: 
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 栏目ID
        menu_id = self.get_param("menuID")
        if menu_id == "":
            return self.response_common("MenuIDEmpty", "栏目ID为空")

        sql = PowerModel().export_sql(menu_id)

        sql_file_name = config.get_value("export_sql_folder", "c:\\") + "SyncSql" + TimeHelper.get_now_format_time("%Y-%m-%d") + ".sql"
        with open(sql_file_name, 'a') as file_handle:
            file_handle.write("{}\n".format(sql))

        return self.response_json_success()


class InsertSqlHandler(StudioBaseHandler):
    """
    :description: sql插入语句导出
    """
    def get_async(self):
        """
        :description: 
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        menu_id = self.get_param("menuID")
        if menu_id == "":
            return self.response_common("MenuIDEmpty", "栏目ID为空")

        sql = PowerModel().export_sql(menu_id, 1)

        sql_file_name = config.get_value("export_sql_folder", "c:\\") + "InsertSql" + TimeHelper.get_now_format_time("%Y-%m-%d") + ".sql"
        with open(sql_file_name, 'a') as file_handle:
            file_handle.write("{}\n".format(sql))

        return self.response_json_success()


class UpdateSqlHandler(StudioBaseHandler):
    """
    :description: sql更新语句导出
    """
    def get_async(self):
        """
        :description: 
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        menu_id = self.get_param("menuID")
        if menu_id == "":
            return self.response_common("MenuIDEmpty", "栏目ID为空")

        sql = PowerModel().export_sql(menu_id, 2)

        sql_file_name = config.get_value("export_sql_folder", "c:\\") + "UpdateSql" + TimeHelper.get_now_format_time("%Y-%m-%d") + ".sql"
        with open(sql_file_name, 'a') as file_handle:
            file_handle.write("{}\n".format(sql))

        return self.response_json_success()


"""
:Author: wang kui
:Date: 2020-03-24 16:32:52
:LastEditTime: 2023-10-19 17:03:15
:LastEditors: ChenXiaolei
:Description: power 用户权限相关接口
"""
from seven_studio.handlers.studio_base import *
from seven_studio.utils.dict import *

from seven_studio.models.db_models.product.product_info_model import *
from seven_studio.models.db_models.product.product_user_model import *
from seven_studio.models.db_models.role.role_power_model_ex import *
from seven_studio.models.db_models.role.role_user_model import *
from seven_studio.models.db_models.role.role_info_model import *
from seven_studio.models.db_models.user.user_info_model_ex import *

from seven_studio.models.seven_model import InvokeResult
from seven_studio.models.power_model import *


class GetUserInfoHandler(StudioBaseHandler):
    """
    :description: 获取当前用户信息
    """
    @login_filter(True)
    def get_async(self):
        """
        :description: 获取当前用户信息
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        user_info = self.get_curr_user_info()
        curr_info = {}
        if user_info:
            curr_info["Account"] = user_info.Account
            curr_info["IsSuper"] = user_info.IsSuper
            curr_info["UserName"] = user_info.UserName
            curr_info["NickName"] = user_info.NickName
            curr_info["JobNo"] = user_info.JobNo
            curr_info["Avatar"] = user_info.Avatar
            curr_info["Phone"] = user_info.Phone
            curr_info["Email"] = user_info.Email
            curr_info["PersonalitySignature"] = user_info.PersonalitySignature

        return self.response_json_success(curr_info)


class GetUserProductListHandler(StudioBaseHandler):
    """
    :description: 获取用户产品列表
    """
    @login_filter(True)
    def get_async(self):
        """
        :description: 获取用户产品列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        user_id = self.request_user_id()
        product_id = self.request_product_id()
        base_manage_context_key = config.get_value("base_manage_context_key", "db_sevenstudio")
        product_info_model = ProductInfoModel(base_manage_context_key)
        product_user_model = ProductUserModel(base_manage_context_key)
        product_data = []
        product_infos = []
        home_info = {"Title": "平台管理", "ImageUrl": "", "ManageUrl": "", "WebUrl": "", "ProductID": 0}
        is_super = self.get_is_super()

        if is_super:
            product_infos = product_info_model.get_list("IsRelease=1")
            if product_id > 0 and self.__has_home_platform_power(self.get_curr_user_info()).ResultCode == "0":
                product_data.append(home_info)
        else:
            if self.__has_home_platform_power(self.get_curr_user_info()).ResultCode == "0":
                product_data.append(home_info)

            product_user_list = product_user_model.get_list("UserID=%s", params=user_id)

            if product_user_list:
                list_str = str([i.ProductID for i in product_user_list if i.ProductID > 0 or product_id == 0]).strip('[').strip(']')
                condition = f"IsRelease=1 AND ProductID IN({list_str})"
                product_infos = product_info_model.get_list(condition)
            elif not product_data:
                return self.response_common("NoData", "没有其他平台权限")

        for product_info in product_infos:
            product_data.append(self.__to_user_product_data(user_id, product_info, is_super))

        return self.response_json_success(product_data)

    def __to_user_product_data(self, user_id, product_info, is_super):
        """
        :description: 判断该用户是否有用户管理和角色管理权限
        :param user_id: 用户id
        :param product_info: 产品信息
        :param is_super: 是否超管
        :return: 
        :last_editors: HuangJingCan
        """
        has_user_manage = False
        has_role_manage = False
        if is_super:
            has_user_manage = True
            has_role_manage = True
        else:
            role_user_list = RoleUserModel(product_info.ManageContextKey).get_list("UserID=%s", params=user_id)
            role_power_list = RolePowerModelEx(product_info.ManageContextKey).get_role_power_list([i.RoleID for i in role_user_list])
            # 用户管理
            if [i for i in role_power_list if i.MenuID == config.get_value("menu_id_user", "80ce2364-368f-47ac-98c8-819fcb521bab")]:
                has_user_manage = True
            # 角色管理
            if [i for i in role_power_list if i.MenuID == config.get_value("menu_id_role", "47a90fe3-012b-49b6-af27-5293124ce827")]:
                has_role_manage = True

        return {
            "Title": product_info.ProductName,
            "SubTitle": product_info.ProductSubName,
            "ImageUrl": product_info.ImageUrl,
            "ManageUrl": product_info.ManageUrl,
            "PowerUrl": product_info.PowerUrl,
            "ProductID": product_info.ProductID,
            "HasUserManage": has_user_manage,
            "HasRoleManage": has_role_manage,
            "IsBrank": product_info.IsBrank,
        }

    def __has_home_platform_power(self, user_info):
        """
        :description: 获取该账号是否有平台管理权限
        :param user_info：用户信息
        :return: 
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()
        invoke_result.ResultCode = "AccountLock"
        invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
        context_key = config.get_value("base_manage_context_key", "db_sevenstudio")
        user_info_model_ex = UserInfoModel(context_key)
        base_user_info = user_info_model_ex.get_entity_by_id(user_info.UserID)
        if not base_user_info:
            return invoke_result
        if base_user_info.IsSuper == 1:
            return InvokeResult()
        role_user_list = RoleUserModel(context_key).get_list("UserID=%s", params=self.request_user_id())
        if not role_user_list:
            return invoke_result
        role_power_list = RolePowerModelEx(context_key).get_role_power_list([i.RoleID for i in role_user_list])
        role_power_info = [i for i in role_power_list if i.MenuID == config.get_value("menu_id_platform", "03E5D2A0-DB59-47F6-8F10-1ACDEFE9BDDD")]

        return InvokeResult() if role_power_info else invoke_result


class FocusPasswordHandler(StudioBaseHandler):
    """
    :description: 强制修改密码弹窗
    """
    @login_filter(True)
    def get_async(self):
        """
        :description: 强制修改密码弹窗
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()
        is_force_password = UserInfoModelEx().is_force_password(self.get_curr_user_info())
        if not is_force_password:
            invoke_result.ResultCode = "Has Change Password"
            invoke_result.ResultMessage = "密码已修改过"

        return self.response_custom(invoke_result)


class FocusChangeUserPwHandler(StudioBaseHandler):
    """
    :description: 强制修改密码
    """
    @login_filter(True)
    def post_async(self):
        """
        :description: 强制修改密码
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 密码
        password = self.get_param("password")

        is_sturdy,message = self.check_password_strength(password)

        if not is_sturdy:
            return self.response_common("Error", message)

        invoke_result = InvokeResult()
        user_info_model_ex = UserInfoModel(config.get_value("base_manage_context_key", "db_sevenstudio"))
        user_info_ex = UserInfoModelEx()
        base_user_info = self.get_base_user_info()

        user_id = base_user_info.UserID if base_user_info else ""
        is_force_password = user_info_ex.is_force_password(base_user_info)
        if not is_force_password:
            return self.response_common("Error", "无需强制更改密码")

        sign_password = user_info_ex.sign_password(password, user_id)
        user_info_model_ex.update_table("Password=%s", "UserID=%s", [sign_password, user_id])

        self.logout(user_id)

        return self.response_custom(invoke_result)


class ChangeCurrUserPwHandler(StudioBaseHandler):
    """
    :description: 修改密码
    """
    @login_filter(True)
    def post_async(self):
        """
        :description: 修改密码
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 旧密码
        password = self.get_param("Password")
        # 新密码
        new_password = self.get_param("NewPassword")

        is_sturdy,message = self.check_password_strength(new_password)

        if not is_sturdy:
            return self.response_common("ErrorPassword", message)
        
        invoke_result = InvokeResult()
        user_info_model_ex = UserInfoModelEx(config.get_value("base_manage_context_key", "db_sevenstudio"))
        base_user_info = self.get_base_user_info()

        user_id = base_user_info.UserID if base_user_info else ""
        if not user_info_model_ex.verify_password(password, base_user_info.Password, user_id):
            return self.response_common("ErrorPassword", "旧密码错误，请重新输入")

        sign_password = user_info_model_ex.sign_password(new_password, user_id)
        user_info_model_ex.update_table("Password=%s", "UserID=%s", [sign_password, user_id])

        self.logout(user_id)

        return self.response_custom(invoke_result)


class GetRoleListHandler(StudioBaseHandler):
    """
    :description: 角色列表
    """
    @login_filter(True)
    def get_async(self):
        """
        :description: 角色列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        manage_context_key = self.get_manage_context_key()
        user_id = self.request_user_id()
        is_super = self.get_is_super()

        condition = "" if is_super else f"ChiefUserID='{user_id}'"
        role_dict_list = RoleInfoModel(manage_context_key).get_dict_list(condition, field="RoleID,RoleName")

        return self.response_json_success(role_dict_list)


class GetRoleUserListHandler(StudioBaseHandler):
    """
    :description: 角色用户列表
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 角色用户列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 数据库db
        manage_context_key = self.get_manage_context_key()
        # 用户id
        user_id = self.request_user_id()
        # 是否超管
        is_super = self.get_is_super()
        # 页索引
        page_index = self.get_page_index()
        # 页大小
        page_size = self.get_page_size()
        # 查询条件、排序字段
        condition, order = self.get_condition_by_body()

        page_data = PageInfo()
        role_user_dto_list = []
        role_info_model = RoleInfoModel(manage_context_key)

        if not is_super:
            if condition:
                condition += " AND "
            condition += f"ChiefUserID='{user_id}'"

        page_list, total = role_info_model.get_page_list("*", page_index, page_size, condition, "", order)
        if not page_list:
            return self.response_json_success(page_data)

        user_ids_list = [i.ModifyUserID for i in page_list]
        user_ids_str = str(user_ids_list).strip('[').strip(']')
        user_info_list = UserInfoModel(manage_context_key).get_list(f"UserID IN({user_ids_str})")

        role_ids_list = [i.RoleID for i in page_list]
        role_ids_str = str(role_ids_list).strip('[').strip(']')
        role_info_list = RoleUserModel(manage_context_key).get_list(f"RoleID IN({role_ids_str})")

        role_power_list = RolePowerModel(manage_context_key).get_list(f"RoleID IN({role_ids_str})")
        role_power_list = RolePowerEx().get_list_by_role_power_list(role_power_list)

        for curr_role_info in page_list:
            curr_role_user_dto = DictUtil.auto_mapper(RoleUserDto(), curr_role_info.__dict__)
            curr_user_info = [i for i in user_info_list if curr_role_info.ModifyUserID != "" and i.UserID == curr_role_info.ModifyUserID]
            curr_role_user_dto.ModifyUser = curr_user_info[0].UserName if curr_user_info else ""
            curr_role_user_dto.RoleUserIds = [i.UserID for i in role_info_list if i.RoleID == curr_role_info.RoleID]
            curr_role_user_dto.RoleMenuIds = [i.MenuCoteID for i in role_power_list if i.RoleID == curr_role_info.RoleID]
            if curr_role_info.ModifyDate == "1900-01-01 00:00:00":
                curr_role_user_dto.ModifyDate = ""
            role_user_dto_list.append(curr_role_user_dto.__dict__)

        page_data.Data = role_user_dto_list
        page_data.RecordCount = total
        page_data.PageSize = page_size
        page_data.PageIndex = page_index

        return self.response_json_success(page_data)


class GetUserRoleListHandler(StudioBaseHandler):
    """
    :description: 用户角色列表
    """
    @login_filter(True)
    def post_async(self):
        """
        :description: 用户角色列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 数据库db
        manage_context_key = self.get_manage_context_key()
        # 用户id
        user_id = self.request_user_id()
        # 是否超管
        is_super = self.get_is_super()
        # 页索引
        page_index = self.get_page_index()
        # 页大小
        page_size = self.get_page_size()
        # 查询条件、排序字段
        condition, order = self.get_condition_by_body()
        # 产品id
        product_id = config.get_value("product_id")

        page_data = PageInfo()
        user_role_dto_list = []
        user_info_model = UserInfoModel(manage_context_key)

        if not is_super:
            if condition:
                condition += " AND "
            condition += f"ChiefUserID='{user_id}'"

        page_list, total = user_info_model.get_page_list("*", page_index, page_size, condition, "", order)
        if not page_list:
            return self.response_json_success(page_data)

        chief_user_ids_list = [i.ChiefUserID for i in page_list]
        chief_user_ids_str = str(chief_user_ids_list).strip('[').strip(']')
        chief_user_info_list = user_info_model.get_list(f"UserID IN({chief_user_ids_str})")

        user_ids_list = [i.UserID for i in page_list]
        user_ids_str = str(user_ids_list).strip('[').strip(']')
        role_user_list = RoleUserModel(manage_context_key).get_list(f"UserID IN({user_ids_str})")

        product_user_list = []
        if product_id == 0:
            product_user_list = ProductUserModel(config.get_value("base_manage_context_key", "db_sevenstudio")).get_list(f"UserID IN({user_ids_str})")

        for curr_user_info in page_list:
            curr_user_role_dto = DictUtil.auto_mapper(UserRoleDto(), curr_user_info.__dict__)
            curr_user_role_dto.UserRoleIds = [i.RoleID for i in role_user_list if i.UserID == curr_user_info.UserID]
            if product_id == 0:
                curr_user_role_dto.UserProductIds = [i.ProductID for i in product_user_list if i.UserID == curr_user_info.UserID]
            chief_user_info = [i for i in chief_user_info_list if curr_user_info.ChiefUserID and i.UserID == curr_user_info.ChiefUserID]
            curr_user_role_dto.ChiefUserName = chief_user_info[0].UserName if chief_user_info else ""
            if curr_user_role_dto.LoginDate == "1900-01-01 00:00:00":
                curr_user_role_dto.LoginDate = ""
            user_role_dto_list.append(curr_user_role_dto.__dict__)

        page_data.Data = user_role_dto_list
        page_data.RecordCount = total
        page_data.PageSize = page_size
        page_data.PageIndex = page_index

        return self.response_json_success(page_data)


class SaveUserHandler(StudioBaseHandler):
    """
    :description: 保存用户
    """
    @login_filter(True)
    def post_async(self):
        """
        :description: 保存用户
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 用户id（空为新增）
        user_id = self.get_param("UserID")
        # 账号
        account = self.get_param("Account")
        # 密码
        password = self.get_param("Password")
        # 电子邮箱
        email = self.get_param("Email")
        # 用户真实名称
        user_name = self.get_param("UserName")
        # 用户昵称
        nick_name = self.get_param("NickName")
        # 工号
        job_no = self.get_param("JobNo")
        # 用户电话
        phone = self.get_param("Phone")
        # 用户头像
        avatar = self.get_param("Avatar")
        # 用户角色列表（多个角色逗号分隔）
        user_role_id_str = self.get_param("UserRoleIdStr")
        # 用户产品列表（多个产品逗号分隔）
        user_product_id_str = self.get_param("UserProductIdStr")
        # 是否修改密码
        change_pw = bool(self.get_param("ChangePw", False))

        manage_context_key = self.get_manage_context_key()
        is_super = self.get_is_super()
        curr_user_id = self.request_user_id()
        product_id = self.request_product_id()

        # 验证数据
        if account == "":
            return self.response_common("AccountEmpty", "账号为空")

        user_info_model = UserInfoModel(self.get_manage_context_key())
        user_info = UserInfo()
        if user_id != "":
            user_info = user_info_model.get_entity_by_id(user_id)
            if not user_info:
                return self.response_common("NoExit", "用户不存在")
            user_info_c = user_info_model.get_entity("Account=%s AND UserID!=%s", params=[account, user_id])
        else:
            user_info_c = user_info_model.get_entity("Account=%s", params=account)

        if user_info_c:
            return self.response_common("Exit", "账号已存在")

        user_info.Account = account
        user_info.Email = email
        user_info.UserName = user_name
        user_info.NickName = nick_name
        user_info.JobNo = job_no
        user_info.Phone = phone
        user_info.Avatar = avatar
        if not self.get_is_super():
            user_info.ChiefUserID = self.request_user_id()

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        is_add = user_id == ""
        result = power_model.set_user(user_info, user_role_id_str.split(","), user_product_id_str.split(","), password, change_pw, is_add)

        return self.response_json_success(result)


class SaveCurrUserHandler(StudioBaseHandler):
    """
    :description: 保存用户
    """
    @login_filter(True)
    def post_async(self):
        """
        :description: 保存用户
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 用户id
        user_id = self.request_user_id()
        # 电子邮箱
        email = self.get_param("Email")
        # 用户昵称
        nick_name = self.get_param("NickName")
        # 用户电话
        phone = self.get_param("Phone")
        # 用户头像
        avatar = self.get_param("Avatar")
        # 个性签名
        personality_signature = self.get_param("PersonalitySignature")

        user_info_model = UserInfoModel(self.get_manage_context_key())
        user_info = user_info_model.get_entity_by_id(user_id)
        if user_id == "" or not user_info:
            return self.response_common("Exit", "账号不存在")

        user_info.Email = email
        user_info.NickName = nick_name
        user_info.Phone = phone
        user_info.Avatar = avatar
        user_info.PersonalitySignature = personality_signature

        user_info_model.update_entity(user_info, field_list=["Email", "NickName", "Phone", "Avatar", "PersonalitySignature"])

        return self.response_json_success(user_info)


class GetUserListHandler(StudioBaseHandler):
    """
    :description: 用户列表
    """
    @login_filter(True)
    def get_async(self):
        """
        :description: 用户列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        manage_context_key = self.get_manage_context_key()
        user_id = self.request_user_id()
        is_super = self.get_is_super()

        condition = "" if is_super else f"ChiefUserID='{user_id}'"
        user_dict_list = UserInfoModel(manage_context_key).get_dict_list(condition, field="UserID,Account,UserName")

        return self.response_json_success(user_dict_list)


class SaveRoleHandler(StudioBaseHandler):
    """
    :description: 修改角色
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 修改角色
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 角色id
        role_id = self.get_param("RoleID")
        # 角色名称
        role_name = self.get_param("RoleName")
        # 备注
        summary = self.get_param("Summary")
        # 角色用户id
        role_user_id_str = self.get_param("RoleUserIdStr")
        # 角色栏目id
        role_menu_id_str = self.get_param("RoleMenuIdStr")
        # 数据库连接串
        manage_context_key = self.get_manage_context_key()
        # 是否超管
        is_super = self.get_is_super()
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 产品id
        product_id = self.request_product_id()

        # 验证数据
        if role_name == "":
            return self.response_common("RoleNameEmpty", "角色名为空")

        role_info_model = RoleInfoModel(self.get_manage_context_key())
        role_info = RoleInfo()
        if role_id != "":
            role_info = role_info_model.get_entity_by_id(role_id)
            if not role_info:
                return self.response_common("NoExit", "角色不存在")
            role_info_c = role_info_model.get_entity("RoleName=%s and RoleID!=%s", params=[role_name, role_id])
            if role_info_c:
                return self.response_common("NoExit", "角色名已存在")
        else:
            role_info_c = role_info_model.get_entity("RoleName=%s", params=role_name)
            if role_info_c:
                return self.response_common("NoExit", "角色名已存在")
            role_info.RoleID = UUIDHelper.get_uuid()

        if not self.get_is_super():
            role_info.ChiefUserID = curr_user_id

        role_info.RoleName = role_name
        role_info.Summary = summary
        role_info.ModifyDate = TimeHelper.get_now_format_time()
        role_info.ModifyUserID = self.request_user_id()

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        is_add = role_id == ""
        result = power_model.set_role(role_info, role_user_id_str.split(","), role_menu_id_str.split(","), is_add)
        result.ModifyUser = self.get_curr_user_info().UserName

        return self.response_json_success(result.__dict__)


class RemoveRoleUserHandler(StudioBaseHandler):
    """
    :description: 删除用户角色
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除用户角色
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 数据库连接串
        manage_context_key = self.get_manage_context_key()
        # 是否超管
        is_super = self.get_is_super()
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 产品id
        product_id = self.request_product_id()
        # 角色id
        role_id = self.get_param("roleID")
        # 用户id
        user_id = self.get_param("userID")

        if role_id == "":
            return self.response_common("EmptyRoleID", "角色ID为空")
        if user_id == "":
            return self.response_common("EmptyUserID", "用户ID为空")

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        power_model.remove_role_user(role_id, user_id)

        return self.response_json_success()


class DeleteRoleHandler(StudioBaseHandler):
    """
    :description: 删除角色
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除用户角色
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 角色id
        role_id = self.get_param("RoleID")

        if role_id == "":
            return self.response_common("EmptyRoleID", "角色ID为空")

        manage_context_key = self.get_manage_context_key()

        RoleUserModel(manage_context_key).del_entity("RoleID=%s", role_id)
        RolePowerModel(manage_context_key).del_entity("RoleID=%s", role_id)
        RoleInfoModel(manage_context_key).del_entity("RoleID=%s", role_id)

        return self.response_json_success()


class DeleteUserHandler(StudioBaseHandler):
    """
    :description: 删除用户
    """
    @login_filter(True)
    @power_filter(True)
    @filter_check_params("UserID")
    def get_async(self):
        """
        :description: 删除用户
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 要删除的用户id
        user_id = self.get_param("UserID")
        # 数据库连接串
        manage_context_key = self.get_manage_context_key()
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 产品id
        product_id = self.request_product_id()
        # 是否超管
        is_super = self.get_is_super()

        if user_id == "":
            return self.response_common("EmptyUserID", "用户ID为空")

        if user_id == self.request_user_id():
            return self.response_common("RemoveLimit", "当前账号不能删除")

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        power_model.remove_user(curr_user_id, user_id)

        self.logout(user_id)

        return self.response_json_success()


class ModifyUserStatusHandler(StudioBaseHandler):
    """
    :description: 更新用户状态
    """
    @login_filter(True)
    @power_filter(True)
    @filter_check_params("UserID,IsLock")
    def get_async(self):
        """
        :description: 更新用户状态
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 用户id
        user_id = self.get_param("UserID")
        # 是否锁定
        is_lock = int(self.get_param("IsLock", -1))
        # 数据库连接串
        manage_context_key = self.get_manage_context_key()
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 是否超管
        is_super = self.get_is_super()

        if user_id == "":
            return self.response_json_error_params()

        if is_lock not in [0, 1]:
            return self.response_json_error_params()

        user_info_model = UserInfoModel(manage_context_key)
        user_info = UserInfoModel(manage_context_key).get_entity_by_id(user_id)
        if not user_info:
            return self.response_common("NoExit", "用户不存在")

        if not is_super and user_info.ChiefUserID != curr_user_id:
            return self.response_common("NoExit", "用户不存在")

        user_info_model.update_table("IsLock=%s", "UserID=%s", [is_lock, user_id])

        return self.response_json_success()


class ResetUserPasswordHandler(StudioBaseHandler):
    """
    :description: 重置密码
    """
    @login_filter(True)
    @power_filter(True)
    @filter_check_params("UserID")
    def get_async(self):
        """
        :description: 重置密码
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 用户id
        user_id = self.get_param("UserID")
        # 数据库连接串
        base_manage_context_key = config.get_value("base_manage_context_key", "db_sevenstudio")
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 是否超管
        is_super = self.get_is_super()

        user_info_model = UserInfoModel(base_manage_context_key)
        user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
        if not user_info:
            return self.response_common("NoExit", "用户不存在")

        if not is_super and user_info.ChiefUserID != curr_user_id:
            return self.response_common("NoExit", "用户不存在")

        sign_password = UserInfoModelEx().sign_password("", user_id)

        user_info_model.update_table("FaildLoginCount=0,Password=%s", "UserID=%s", [sign_password, user_id])

        self.logout(user_id)

        return self.response_json_success()


class ResetUserFaildLoginCountHandler(StudioBaseHandler):
    """
    :description: 登录失败重置
    """
    @login_filter(True)
    @power_filter(True)
    @filter_check_params("UserID")
    def get_async(self):
        """
        :description: 登录失败重置
        :param {type}
        :return:
        :last_editors: HuangJingCan
        """
        user_id = self.get_param("UserID")
        # 数据库连接串
        base_manage_context_key = config.get_value("base_manage_context_key", "db_sevenstudio")
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 是否超管
        is_super = self.get_is_super()

        user_info_model = UserInfoModel(base_manage_context_key)
        user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
        if not user_info:
            return self.response_common("NoExit", "用户不存在")

        if not is_super and user_info.ChiefUserID != curr_user_id:
            return self.response_common("NoExit", "用户不存在")

        user_info_model.update_table("FaildLoginCount=0", "UserID=%s", [user_id])

        return self.response_json_success()


class RemoveUserAllRoleHandler(StudioBaseHandler):
    """
    :description: 收回权限
    """
    @login_filter(True)
    @power_filter(True)
    @filter_check_params("UserID")
    def get_async(self):
        """
        :description: 收回权限
        :param {type}
        :return:
        :last_editors: HuangJingCan
        """
        # 被收回权限的用户id
        user_id = self.get_param("UserID")
        # 数据库连接串
        manage_context_key = self.get_manage_context_key()
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 是否超管
        is_super = self.get_is_super()

        role_user_model = RoleUserModel(manage_context_key)

        if is_super:
            role_user_model.del_entity("UserID=%s", user_id)
        else:
            user_info = role_user_model.get_entity_by_id(user_id)
            if user_info and user_info.ChiefUserID != curr_user_id:
                role_user_model.del_entity("UserID=%s", user_id)

        return self.response_json_success()


class CopyUserRoleHandler(StudioBaseHandler):
    """
    :description: 复制权限
    """
    @login_filter(True)
    @power_filter(True)
    @filter_check_params("userID,copyUserID")
    def get_async(self):
        """
        :description: 复制权限
        :param {type}
        :return:
        :last_editors: HuangJingCan
        """
        # 复制用户id
        copy_user_id = self.get_param("copyUserID")
        # 用户id
        user_id = self.get_param("userID")
        # 数据库连接串
        manage_context_key = self.get_manage_context_key()
        # 当前用户id
        curr_user_id = self.request_user_id()
        # 产品id
        product_id = self.request_product_id()
        # 是否超管
        is_super = self.get_is_super()

        power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
        power_model.copy_user_role(copy_user_id, user_id)

        return self.response_json_success()


"""
:Author: HuangJingCan
:Date: 2020-03-17 16:12:54
:LastEditTime: 2023-02-07 17:17:49
:LastEditors: HuangJingCan
:Description: 文件操作相关接口
"""
from seven_studio.handlers.studio_base import *

from seven_studio.models.db_models.file.file_storage_path_model import *
from seven_studio.models.db_models.file.file_resource_model import *
from seven_studio.models.db_models.file.file_restrict_model import *
from seven_studio.models.db_models.file.file_water_image_model import *
from seven_studio.models.db_models.file.file_history_model import *
from seven_studio.models.seven_model import InvokeResult
from seven_studio.libs.file.ks3 import *


class GetStoragePathListHandler(StudioBaseHandler):
    """
    :description: 获取存储配置列表
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 获取存储配置列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 数据库连接串
        file_storage_path_model = FileStoragePathModel(self.get_file_context_key())
        # 页索引
        page_index = self.get_page_index()
        # 页大小
        page_size = self.get_page_size()
        # 查询条件,排序字段
        condition, order = self.get_condition_by_body()

        p_dict, total = file_storage_path_model.get_dict_page_list("*", page_index, page_size, condition, "", order)

        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))


class GetStoragePathDataHandler(StudioBaseHandler):
    """
    :description: 获取存储配置
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 获取存储配置
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        file_storage_path_model = FileStoragePathModel(self.get_file_context_key())
        p_dict = file_storage_path_model.get_dict_list("", "FileStoragePathID,StoragePathName")

        return self.response_json_success(p_dict)


class SaveStoragePathHandler(StudioBaseHandler):
    """
    :description: 保存存储配置
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 保存存储配置
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 存储标识
        file_storage_path_id = self.get_param("FileStoragePathID")
        # 存储名称
        storage_path_name = self.get_param("StoragePathName")
        # 存储类型1本地存储2FTP3文件系统
        storage_type_id = int(self.get_param("StorageTypeID", "0"))
        # 虚目录
        virtual_name = self.get_param("VirtualName")
        # 存储地址
        storage_path = self.get_param("StoragePath")
        # IP
        ip_address = self.get_param("IPAddress")
        # 帐号
        account = self.get_param("Account")
        # 密码
        password = self.get_param("Password")
        # 端口
        port = self.get_param("Port")
        # 配置文件
        storage_config = self.get_param("StorageConfig")

        # 验证数据
        if storage_path_name == "":
            return self.response_common("StoragePathNameEmpty", "存储名称参数为空")

        file_storage_path_model = FileStoragePathModel(self.get_file_context_key())
        file_storage_path = FileStoragePath()
        if file_storage_path_id != "":
            file_storage_path = file_storage_path_model.get_entity_by_id(file_storage_path_id)
            if not file_storage_path:
                return self.response_common("NoExist", "数据不存在")

        # 赋值
        file_storage_path.StoragePathName = storage_path_name
        file_storage_path.StorageTypeID = storage_type_id
        file_storage_path.VirtualName = virtual_name
        file_storage_path.StoragePath = storage_path
        file_storage_path.IPAddress = ip_address
        file_storage_path.Account = account
        file_storage_path.Password = password
        file_storage_path.Port = port
        file_storage_path.StorageConfig = storage_config

        if file_storage_path.FileStoragePathID != "":
            file_storage_path_model.update_entity(file_storage_path)
        else:
            file_storage_path.FileStoragePathID = UUIDHelper.get_uuid()
            file_storage_path_model.add_entity(file_storage_path)

        return self.response_json_success(file_storage_path)


class DeleteStoragePathHandler(StudioBaseHandler):
    """
    :description: 删除存储配置
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除存储配置
        :param id：id
        :return: 
        :last_editors: HuangJingCan
        """
        file_storage_path_id = self.get_param("FileStoragePathID")
        if file_storage_path_id == "":
            return self.response_common("FileStoragePathIDEmpty", "存储配置ID为空")

        FileStoragePathModel(self.get_file_context_key()).del_entity("FileStoragePathID=%s", file_storage_path_id)

        return self.response_json_success()


class GetResourceListHandler(StudioBaseHandler):
    """
    :description: 获取文件配置列表
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 获取文件配置列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        # 文件上下文配置
        file_resource_model = FileResourceModel(self.get_file_context_key())
        # 页索引
        page_index = self.get_page_index()
        # 页大小
        page_size = self.get_page_size()
        # 查询条件,排序字段
        condition, order = self.get_condition_by_body()

        p_dict, total = file_resource_model.get_dict_page_list("*", page_index, page_size, condition, "", order)

        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))


class GetResourceInfoHandler(StudioBaseHandler):
    """
    :description: 获取文件配置
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 获取文件配置
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        file_resource_model = FileResourceModel(self.get_file_context_key())
        p_dict = file_resource_model.get_dict_by_id(self.get_page_cote_id())

        return self.response_json_success(p_dict)


class SaveResourceHandler(StudioBaseHandler):
    """
    :description: 保存文件配置
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 保存文件配置
        :param id：id
        :return: 
        :last_editors: HuangJingCan
        """
        # 文件资源标识
        file_resource_id = self.get_param("FileResourceID")
        # 文件资源名称
        file_resource_name = self.get_param("FileResourceName")
        # 文件资源代码
        file_resource_code = self.get_param("FileResourceCode")

        # 验证数据
        if file_resource_name == "":
            return self.response_common("FileResourceNameEmpty", "FileResourceName参数为空")
        if file_resource_code == "":
            return self.response_common("FileResourceCodeEmpty", "FileResourceCode参数为空")

        file_resource_model = FileResourceModel(self.get_file_context_key())
        file_resource = FileResource()
        if file_resource_id != "":
            file_resource = file_resource_model.get_entity_by_id(file_resource_id)
            if not file_resource:
                return self.response_common("NoExist", "数据不存在")

        # 赋值保存
        file_resource.FileResourceName = file_resource_name
        file_resource.FileResourceCode = file_resource_code
        file_resource.CreateDate = TimeHelper.get_now_format_time()
        if file_resource_id != "":
            file_resource_model.update_entity(file_resource)
        else:
            file_resource.FileResourceID = UUIDHelper.get_uuid()
            file_resource_model.add_entity(file_resource)

        return self.response_json_success(file_resource)


class DeleteResourceHandler(StudioBaseHandler):
    """
    :description: 删除资源
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除资源
        :param id：id
        :return: 
        :last_editors: HuangJingCan
        """
        file_resource_id = self.get_param("FileResourceID")
        if file_resource_id == "":
            return self.response_common("FileResourceIDEmpty", "资源ID为空")

        FileResourceModel(self.get_file_context_key()).del_entity("FileResourceID=%s", file_resource_id)

        return self.response_json_success()


class GetRestrictListHandler(StudioBaseHandler):
    """
    :description: 获取上传限制
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 获取上传限制
        :param {type} 
        :return: response_json_success
        :last_editors: HuangJingCan
        """
        condition = ""
        con, order = self.get_condition_by_body()
        page_cote_id = self.get_page_cote_id()
        if page_cote_id:
            condition = f"FileResourceID='{page_cote_id}'"
            if con:
                condition = condition + " AND " + con
        else:
            condition = con

        file_context_key = self.get_file_context_key()
        file_restrict_model = FileRestrictModel(file_context_key)
        page_index = self.get_page_index()
        page_size = self.get_page_size()
        source_dict_list = file_restrict_model.get_dict_list(condition)
        if len(source_dict_list) > 0:
            merge_dict_list = FileStoragePathModel(file_context_key).get_dict_list(field="FileStoragePathID,StoragePathName")
            source_dict_list = DictUtil.merge_dict_list(source_dict_list, "FileStoragePathID", merge_dict_list, "FileStoragePathID", "FileStoragePathID,StoragePathName")
        page_dict = self.get_dict_page_info_list(page_index, page_size, source_dict_list)

        return self.response_json_success(page_dict)


class SaveRestrictHandler(StudioBaseHandler):
    """
    :description: SaveRestrict
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: SaveRestrict
        :param id：id
        :return: response_json_success
        :last_editors: HuangJingCan
        """
        # 文件限制标识
        file_restrict_id = self.get_param("FileRestrictID")
        # 存储路经标识
        file_storage_path_id = self.get_param("FileStoragePathID")
        # 文件资源标识
        access_mode_code_type = int(self.get_param("AccessModeCodeType", "0"))
        # 文件访问方式
        path_format_code_type = int(self.get_param("PathFormatCodeType", "0"))
        # 限制名称
        restrict_name = self.get_param("RestrictName")
        # 资源代码
        restrict_code = self.get_param("RestrictCode")
        # 1文件2图片3flash4mid
        file_type = int(self.get_param("FileType", "0"))
        # 文件扩展名
        file_extension = self.get_param("FileExtension")
        # 大小限制单位(K)0不限制
        file_max_size = int(self.get_param("FileMaxSize", "0"))
        # 是否返回尺寸
        is_return_size = int(self.get_param("IsReturnSize", "0"))
        # 是否Md5
        is_md5 = int(self.get_param("IsMd5", "0"))
        # 是否记录文件记录
        is_history = int(self.get_param("IsHistory", "0"))
        # 是否创建水印
        is_water_mark = int(self.get_param("IsWaterMark", "0"))
        # 是否格式化成Jpeg
        is_format_jpeg = int(self.get_param("IsFormatJpeg", "0"))
        # 水印文字
        water_mark_text = self.get_param("WatermarkText")
        # 水平位置
        horizontal_align = int(self.get_param("HorizontalAlign", "0"))
        # 垂直位置
        vertical_align = int(self.get_param("VerticalAlign", "0"))
        # 图片宽度
        image_width = int(self.get_param("ImageWidth", "0"))
        # 图片高度
        image_height = int(self.get_param("ImageHeight", "0"))
        # 质量压缩
        quality_value = int(self.get_param("QualityValue", "0"))
        # 水印类型
        water_mark_type = int(self.get_param("WatermarkType", "0"))
        # 水印标识
        water_image_id = self.get_param("WaterImageID")

        # 验证数据
        if restrict_name == "":
            return self.response_common("RestrictNameEmpty", "RestrictName参数为空")
        if restrict_code == "":
            return self.response_common("RestrictCodeEmpty", "RestrictCode参数为空")

        file_restrict_model = FileRestrictModel(self.get_file_context_key())
        file_restrict = FileRestrict()
        if file_restrict_id != "":
            file_restrict = file_restrict_model.get_entity_by_id(file_restrict_id)
            if not file_restrict:
                return self.response_common("NoExistFileResource", "数据不存在")
        page_cote_id = self.get_page_cote_id()
        file_resource = FileResourceModel(self.get_file_context_key()).get_entity_by_id(page_cote_id)
        if not file_resource:
            return self.response_common("NoExistFileResource", "数据不存在")

        # 赋值保存
        file_restrict.ResourceCode = file_resource.FileResourceCode
        file_restrict.FileResourceID = page_cote_id
        file_restrict.FileStoragePathID = file_storage_path_id
        file_restrict.AccessModeCodeType = access_mode_code_type
        file_restrict.PathFormatCodeType = path_format_code_type
        file_restrict.RestrictName = restrict_name
        file_restrict.RestrictCode = restrict_code
        file_restrict.FileType = file_type
        file_restrict.FileExtension = file_extension
        file_restrict.FileMaxSize = file_max_size
        file_restrict.IsReturnSize = is_return_size
        file_restrict.IsMd5 = is_md5
        file_restrict.IsHistory = is_history
        file_restrict.IsWaterMark = is_water_mark
        file_restrict.IsFormatJpeg = is_format_jpeg
        file_restrict.WatermarkText = water_mark_text
        file_restrict.HorizontalAlign = horizontal_align
        file_restrict.VerticalAlign = vertical_align
        file_restrict.ImageWidth = image_width
        file_restrict.ImageHeight = image_height
        file_restrict.QualityValue = quality_value
        file_restrict.WatermarkType = water_mark_type
        file_restrict.WaterImageID = water_image_id

        if file_restrict_id != "":
            file_restrict_model.update_entity(file_restrict)
        else:
            file_restrict.FileRestrictID = UUIDHelper.get_uuid()
            file_restrict_model.add_entity(file_restrict)

        return self.response_json_success(file_restrict)


class DeleteRestrictHandler(StudioBaseHandler):
    """
    :description: DeleteRestrict
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除
        :param id：id
        :return: 
        :last_editors: HuangJingCan
        """
        file_restrict_id = self.get_param("FileRestrictID")
        if file_restrict_id == "":
            return self.response_common("FileRestrictIDEmpty", "FileRestrictID为空")

        FileRestrictModel(self.get_file_context_key()).del_entity("FileRestrictID=%s", file_restrict_id)

        return self.response_json_success()


class GetWaterImageListHandler(StudioBaseHandler):
    """
    :description: 获取水印图片列表
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 获取水印图片列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        file_water_image_model = FileWaterImageModel(self.get_file_context_key())
        page_index = self.get_page_index()
        page_size = self.get_page_size()
        condition, order = self.get_condition_by_body()

        p_dict, total = file_water_image_model.get_dict_page_list("*", page_index, page_size, condition, "", order)

        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))


class GetWaterImageDataHandler(StudioBaseHandler):
    """
    :description: 获取水印图片
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 获取水印图片
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        file_water_image_model = FileWaterImageModel(self.get_file_context_key())
        p_dict = file_water_image_model.get_dict_list(field="WaterImageID,WaterName")

        return self.response_json_success(p_dict)


class SaveWaterImageHandler(StudioBaseHandler):
    """
    :description: 保存图片水印
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 保存图片水印
        :param WaterImageID：水印图片id 
        :param WaterImagePath：水印图片路径
        :param WaterName：水印图片名称
        :return: response_json_success
        :last_editors: HuangJingCan
        """
        # 水印id
        water_image_id = self.get_param("WaterImageID")
        # 水印地址
        water_image_path = self.get_param("WaterImagePath")
        # 水印名称
        water_name = self.get_param("WaterName")

        # 验证数据
        if water_name == "":
            return self.response_common("WaterNameEmpty", "水印名称为空")

        file_water_image_model = FileWaterImageModel(self.get_file_context_key())
        file_water_image = FileWaterImage()
        if water_image_id != "":
            file_water_image = file_water_image_model.get_entity_by_id(water_image_id)
            if not file_water_image:
                return self.response_common("NoExist", "数据不存在")

        # 赋值
        file_water_image.WaterImagePath = water_image_path
        file_water_image.WaterName = water_name

        if water_image_id != "":
            file_water_image_model.update_entity(file_water_image)
        else:
            file_water_image.WaterImageID = UUIDHelper.get_uuid()
            file_water_image_model.add_entity(file_water_image)

        return self.response_json_success(file_water_image)


class DeleteWaterImageHandler(StudioBaseHandler):
    """
    :description: 删除水印图
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除
        :param WaterImageID：主键id
        :return: 
        :last_editors: HuangJingCan
        """
        # 水印图id
        water_image_id = self.get_param("WaterImageID")

        if water_image_id == "":
            return self.response_common("WaterImageIDEmpty", "WaterImageID为空")

        FileWaterImageModel(self.get_file_context_key()).del_entity("WaterImageID=%s", water_image_id)

        return self.response_json_success()


class GetHistoryListHandler(StudioBaseHandler):
    """
    :description: 获取文件历史
    """
    @login_filter(True)
    @power_filter(True)
    def post_async(self):
        """
        :description: 获取文件历史
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        file_history_model = FileHistoryModel(self.get_file_context_key())
        page_index = self.get_page_index()
        page_size = self.get_page_size()
        condition, order = self.get_condition_by_body()

        p_dict, total = file_history_model.get_dict_page_list("*", page_index, page_size, condition, "", order)

        return self.response_json_success(self.get_dict_page_info_list(page_index, page_size, p_dict, total))


class DeleteHistoryHandler(StudioBaseHandler):
    """
    :description: 删除文件历史记录
    """
    @login_filter(True)
    @power_filter(True)
    def get_async(self):
        """
        :description: 删除文件历史记录
        :param FileHistoryID：主键id
        :return: 
        :last_editors: HuangJingCan
        """
        # 文件历史记录id
        file_history_id = self.get_param("FileHistoryID")

        if file_history_id == "":
            return self.response_common("FileHistoryIDEmpty", "FileHistoryID为空")

        result = 0
        file_context_key = self.get_file_context_key()
        file_history_model = FileHistoryModel(file_context_key)
        file_history = file_history_model.get_entity_by_id(file_history_id)
        if file_history:
            file_storage_path_model = FileStoragePathModel(file_context_key)
            file_storage_path = file_storage_path_model.get_entity_by_id(file_history.FileStoragePathID)
            if file_storage_path:
                if file_storage_path.VirtualName == "Seven.Manage.KS3":
                    result = KS3.delete(file_storage_path.StorageConfig, file_history.FileUrl)
                    if result == 0:
                        # 判断文件是否还在云服务器，不存在就删除本地历史记录
                        contents = KS3.get(file_storage_path.StorageConfig, file_history.FileUrl)
                        if contents == "":
                            result = 1
                elif file_storage_path.StorageTypeID == 1:
                    if os.path.exists(file_history.FileUrl):
                        os.remove(file_history.FileUrl)
                    result = 1
            else:
                result = 1

        if result > 0:
            file_history_model.del_entity("FileHistoryID=%s", file_history_id)

        return self.response_json_success()


"""
:Author: ChenXiaolei
:Date: 2020-03-24 10:42:34
:LastEditTime: 2023-10-19 16:36:17
:LastEditors: ChenXiaolei
:Description: StudioBaseHandler
"""
import ast
from seven_framework.web_tornado.base_handler.base_cookie_handler import *
from seven_framework.redis import *

from seven_studio.models.db_models.product.product_info_model import *
from seven_studio.models.db_models.user.user_login_model import *
from seven_studio.models.db_models.user.user_info_model import *
from seven_studio.models.db_models.menu.menu_info_model_ex import *
from seven_studio.models.db_models.role.role_user_model import *
from seven_studio.models.db_models.role.role_power_model_ex import *
from seven_studio.models.db_models.log.log_action_model import *
from seven_studio.models.seven_model import *
from seven_studio.models.enum import *


class StudioBaseHandler(BaseCookieHandler):
    """
    :description: StudioBaseHandler
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    def options_async(self):
        self.response_json_success()

    def check_xsrf_cookie(self):
        return

    def add_action_log(self, module_code, content, record_time=None):
        """
        :description: 添加平台操作行为日志
        :param module_code: 模块标识
        :param content: 日志内容
        :param record_time: 日志时间 默认当前时间
        :return 成功 True 失败 False
        :last_editors: ChenXiaolei
        """
        op_result = False
        try:
            if not record_time:
                record_time = TimeHelper.get_now_timestamp()
            user_id = self.request_user_id()
            client_ip = self.get_remote_ip()
            log_action = LogAction()
            log_action.module_code = module_code
            log_action.user_id = user_id
            log_action.content = content
            log_action.record_time = record_time
            log_action.client_ip = client_ip

            if LogActionModel().add_entity(log_action) > 0:
                op_result = True
            return op_result
        except:
            self.logger_error.error(f"添加平台行为日志时异常:{traceback.format_exc()}")
            return False

    def json_dumps(self, rep_dic):
        """
        :description: 对象编码成Json字符串
        :param rep_dic：字典对象
        :return: str
        :last_editors: HuangJianYi
        """
        try:
            if rep_dic == "":
                return ""
            rep_dic = ast.literal_eval(rep_dic)
        except Exception:
            pass

        if hasattr(rep_dic, '__dict__'):
            rep_dic = rep_dic.__dict__

        return json.dumps(
            rep_dic,
            ensure_ascii=False,
            cls=JsonEncoder,
            default=lambda x: (datetime.datetime.strftime(x, '%Y-%m-%d %H:%M:%S') if isinstance(x, datetime.datetime) else x.__dict__) if not isinstance(x, decimal.Decimal) else float(x),
            sort_keys=False,
            indent=None,
        )

    def json_loads(self, rep_str):
        """
        :description: 将Json字符串解码成python对象
        :param rep_str：str
        :return: dict
        :last_editors: HuangJingCan
        """
        try:
            return json.loads(rep_str)
        except Exception as ex:
            return json.loads(self.json_dumps(rep_str))

    def response_custom(self, rep_dic):
        """
        :description: 输出公共json模型
        :param rep_dic: 字典类型数据
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.http_reponse(self.json_dumps(rep_dic))

    def response_common(self, result_code, result_message, data=None):
        """
        :description: 输出公共json模型
        :param result_code: 字符串，服务端返回的错误码
        :param result_message: 字符串，服务端返回的错误信息
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        if hasattr(data, '__dict__'):
            data = data.__dict__
        rep_dic = {
            'ResultCode': result_code,
            'ResultMessage': result_message,
            'Data': data,
        }
        self.http_reponse(self.json_dumps(rep_dic))

    def response_json_success(self, data=None, desc='调用成功'):
        """
        :description: 通用成功返回json结构
        :param data: 返回结果对象，即为数组，字典
        :param desc: 字符串，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.response_common("0", desc, data)

    def response_json_error(self, desc='error'):
        """
        :description: 通用错误返回json结构
        :param desc: 字符串，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.response_common("1", desc)

    def response_json_error_params(self, desc='params error'):
        """
        :description: 参数错误返回json结构
        :param desc: 字符串，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.response_common("1", desc)

    def redis_init(self, db=None):
        """
        :description: redis初始化
        :return: redis_cli
        :last_editors: HuangJingCan
        """
        return RedisHelper.redis_init(config_dict=config.get_value("redis"))

    def set_default_headers(self):
        allow_origin_list = config.get_value("allow_origin_list")
        origin = self.request.headers.get("Origin")
        if origin in allow_origin_list:
            self.set_header("Access-Control-Allow-Origin", origin)

        self.set_header("Access-Control-Allow-Headers", "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS,PUT,DELETE,PATCH")
        self.set_header("Access-Control-Allow-Credentials", "true")

    def request_header_token(self):
        header_token = {}
        if "User-Token" in self.request.headers:
            reqInfoList = str.split(self.request.headers["User-Token"], ";")
            for info in reqInfoList:
                kv = str.split(info, "=")
                header_token[kv[0]] = kv[1]
        return header_token

    def request_user_id(self):
        header_token = self.request_header_token()
        return header_token["UserID"] if header_token.__contains__("UserID") else ""

    def request_user_id_md5(self):
        header_token = self.request_header_token()
        return (header_token["UserIDMD5"] if header_token.__contains__("UserIDMD5") else "")

    def request_user_token(self):
        header_token = self.request_header_token()
        return (header_token["UserToken"] if header_token.__contains__("UserToken") else "")

    def request_product_id(self):
        header_product_id = ""
        if self.request.headers.__contains__("Manage-Productid"):
            header_product_id = self.request.headers["Manage-Productid"]
        product_id = int(header_product_id) if header_product_id.strip() != "" else 0
        if product_id == 0:
            product_id = int(self.get_param("manage-productid", "0"))
        return product_id

    def request_manage_page_id(self):
        return (self.request.headers["Manage-PageID"] if self.request.headers.__contains__("Manage-PageID") else "")

    def get_product_info(self):
        product_id = self.request_product_id()
        return (ProductInfoModel(config.get_value("base_manage_context_key", "db_sevenstudio")).get_entity_by_id(product_id) if product_id > 0 else None)

    def get_curr_user_info(self):
        user_id = self.request_user_id()
        return (UserInfoModel(self.get_manage_context_key()).get_entity_by_id(user_id) if user_id else None)

    def get_base_user_info(self):
        user_id = self.request_user_id()
        return (UserInfoModel(config.get_value("base_manage_context_key", "db_sevenstudio")).get_entity_by_id(user_id) if user_id else None)

    def get_is_super(self):
        base_user_info = self.get_base_user_info()
        return base_user_info.IsSuper == 1 if base_user_info else False

    def get_manage_context_key(self):
        manage_context_key = config.get_value("manage_context_key", "db_sevenstudio")
        product_info = self.get_product_info()
        if product_info:
            manage_context_key = product_info.ManageContextKey
        return manage_context_key

    def get_file_context_key(self):
        file_context_key = config.get_value("file_context_key", "db_sevenstudio")
        product_info = self.get_product_info()
        if product_info:
            file_context_key = product_info.FileContextKey
        return file_context_key

    def get_log_context_key(self):
        log_context_key = config.get_value("log_context_key", "db_sevenstudio")
        product_info = self.get_product_info()
        if product_info:
            log_context_key = product_info.LogContextKey
        return log_context_key

    def get_page_index(self):
        page_index = 0
        r_page_index = self.get_param("PageIndex", "")
        if r_page_index != "":
            dict_page_index = json.loads(r_page_index)
            if dict_page_index and dict_page_index.__contains__("Value"):
                page_index = dict_page_index["Value"]
        return page_index

    def get_page_size(self):
        page_size = 10
        r_page_size = self.get_param("PageSize", "")
        if r_page_size != "":
            dict_page_size = json.loads(r_page_size)
            if dict_page_size and dict_page_size.__contains__("Value"):
                page_size = dict_page_size["Value"]
        return page_size

    def get_page_cote_id(self):
        page_id = self.request_manage_page_id()
        if page_id != "":
            return page_id.split("$")[1] if page_id.__contains__("$") else ""
        else:
            return ""

    def get_dict_page_info_list(self, page_index, page_size, p_dict, total=0):
        """
        :description: 获取分页信息
        :param page_index：页索引
        :param page_size：页大小
        :param p_dict：字典列表
        :return: 
        :last_editors: HuangJingCan
        """
        page_info = PageInfo()
        page_info.PageIndex = page_index
        page_info.PageSize = page_size
        page_info.RecordCount = total if total > 0 else len(p_dict)
        page_info.Data = p_dict
        page_info = page_info.get_entity_by_page_info(page_info)
        return page_info.__dict__

    def get_dict_by_keys(self, source_dict, keys):
        """
        :description: 根据key搜索字典，返回key相关字典
        :param source_dict
        :param keys
        :return: 值
        :last_editors: HuangJingCan
        """
        if isinstance(source_dict, str):
            source_dict = json.loads(source_dict)
        key_list = list(keys.split(","))
        return {i: source_dict[i] for i in key_list if i in source_dict}

    def get_condition_by_body(self):
        """
        :description: 获取页面查询条件
        :param {type} 
        :return: condition, order
        :last_editors: HuangJingCan
        """
        condition = ""
        order = ""
        body_dict = self.request_body_to_dict()
        for item in body_dict:
            if not item.__contains__("PageIndex") and not item.__contains__("PageSize"):
                # print(body_dict[item])
                query_method = json.loads(body_dict[item]).get("QueryMethod")
                query_Value = json.loads(body_dict[item]).get("Value")
                query_type = json.loads(body_dict[item]).get("QueryType")
                # query_data_type = json.loads(body_dict[item]).get("QueryDataType")
                if query_type == "Query" and query_Value != "":
                    if condition != "":
                        condition += " AND "
                    if query_method == QueryMethod.Contains.value:
                        condition += f"{item} LIKE '%{query_Value}%'"
                    elif query_method == QueryMethod.StartsWith.value:
                        condition += f"{item} LIKE '{query_Value}%'"
                    elif query_method == QueryMethod.EndsWith.value:
                        condition += f"{item} LIKE '%{query_Value}'"
                    elif query_method == QueryMethod.Equal.value:
                        condition += f"{item}={query_Value}"
                    elif query_method == QueryMethod.GreaterThan.value:
                        condition += f"{item}>{query_Value}"
                    elif query_method == QueryMethod.GreaterThanOrEqual.value:
                        condition += f"{item}>={query_Value}"
                    elif query_method == QueryMethod.LessThan.value:
                        condition += f"{item}<{query_Value}"
                    elif query_method == QueryMethod.LessThanOrEqual.value:
                        condition += f"{item}<={query_Value}"
                    elif query_method == QueryMethod.NotEqual.value:
                        condition += f"{item}<>{query_Value}"
                if query_type == "Sort" and query_Value != "":
                    order = f"{item} {query_Value}"

        return condition, order

    def get_system_user_table(self):
        """
        :description: 获取系统用户
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        return UserInfoModel(self.get_manage_context_key()).get_dict_list()

    def logout(self, user_id):
        """
        :description: 用户退出
        :param user_id：用户id
        :return: 
        :last_editors: HuangJingCan
        """
        if user_id.strip() == "":
            return
        if config.get_value("login_type", "redis") == "redis":
            self.redis_init().hdel(config.get_value("redis_provider_name_user_login", "user_login"), user_id)
        else:
            UserLoginModel(config.get_value("manage_context_key", "db_sevenstudio")).del_entity("UserID=%s", user_id)

        self.clear_user_cookie()

    def clear_user_cookie(self):
        """
        :description: 清理用户登录cookie
        """
        self.clear_cookie("UserID")
        self.clear_cookie("UserIDMD5")
        self.clear_cookie("UserToken")

    def login_cookie(self, user_login):
        """
        :description: 登录状态设置
        :param user_login: 登录信息
        :return: user_login
        :last_editors: HuangJingCan
        """
        if config.get_value("login_type", "redis") == "redis":
            self.redis_init().hset(config.get_value("redis_provider_name_user_login", "user_login"), user_login.UserID, self.json_dumps(user_login))
        else:
            user_login_base = UserLoginModel(config.get_value("base_manage_context_key", "db_sevenstudio"))
            user_login_base.add_update_entity(user_login, "UserIDMD5=%s,ExpireTime=%s,UserToken=%s", [user_login.UserIDMD5, user_login.ExpireTime, user_login.UserToken])

        cookie_domain = config.get_value("cookie_domain")
        if cookie_domain:
            self.set_cookie("UserID", user_login.UserID, domain=cookie_domain)
            self.set_cookie("UserIDMD5", user_login.UserIDMD5, domain=cookie_domain)
            self.set_cookie("UserToken", user_login.UserToken, domain=cookie_domain)
        else:
            self.set_cookie("UserID", user_login.UserID)
            self.set_cookie("UserIDMD5", user_login.UserIDMD5)
            self.set_cookie("UserToken", user_login.UserToken)

    def check_power_menu(self, api_path, cote_id):
        """
        :description: 权限判断
        :param api_path：路径
        :param cote_id：权限码值
        :return: True or False
        :last_editors: HuangJingCan
        """
        manage_context_key = self.get_manage_context_key()
        menu_info_list = MenuInfoModel(manage_context_key).get_list(f"ApiPath LIKE '%{api_path}%'")
        if not menu_info_list:
            return False
        if [i for i in menu_info_list if i.IsPower == 0]:
            return True
        role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=self.request_user_id())
        role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
        cote_list = [i for i in role_power_list if i.CoteID == cote_id]
        menu_list = [i.MenuID for i in menu_info_list]
        return bool([i for i in cote_list if menu_list.__contains__(i.MenuID)])

    def auto_mapper(self, s_model, map_dict=None):
        """
        :description: 对象映射（把map_dict值赋值到实体s_model中）
        :param s_model：需要映射的实体对象
        :param map_dict：被映射的实体字典
        :return: 映射后的实体s_model
        """
        if map_dict:
            field_list = s_model.get_field_list()
            for filed in field_list:
                if filed in map_dict:
                    setattr(s_model, filed, map_dict[filed])
        return s_model

    def check_login_user(self, user_id, user_token, is_need_login=True):
        """
        :description: 登录用户检查
        :param user_id：用户id
        :param user_token：用户user_token
        :return: 
        """
        invoke_result = InvokeResult()
        # 登陆日志判断，Redis还是MySQL
        if config.get_value("login_type", "redis") == "redis":
            redis_user_login = self.redis_init().hget(config.get_value("redis_provider_name_user_login", "user_login"), user_id)
            user_login = json.loads(redis_user_login) if redis_user_login else {}
            if not user_login or TimeHelper.format_time_to_datetime(user_login["ExpireTime"]) < TimeHelper.get_now_datetime():
                if not is_need_login:
                    return invoke_result
                self.clear_user_cookie()
                invoke_result.ResultCode = "login_expire"
                invoke_result.ResultMessage = "用户已过期，请重新登录"
                return invoke_result
            if user_login["UserToken"] != user_token:
                if not is_need_login:
                    return invoke_result
                self.clear_user_cookie()
                invoke_result.ResultCode = "login_expire"
                invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
                return invoke_result

            curr_user_info = UserInfoModel(config.get_value("manage_context_key", "db_sevenstudio")).get_entity_by_id(user_id)
            if curr_user_info.IsLock == 1:
                invoke_result.ResultCode = "login_expire"
                invoke_result.ResultMessage = "用户已被锁，请联系管理员"
                return invoke_result

            user_login["ExpireTime"] = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire", 10))
            self.redis_init().hset(config.get_value("redis_provider_name_user_login", "user_login"), user_id, self.json_dumps(user_login))
        else:
            base_manage_context_key = config.get_value("base_manage_context_key", "db_sevenstudio")
            manage_context_key = self.get_manage_context_key()

            user_login_model = UserLoginModel(base_manage_context_key)
            user_login = user_login_model.get_entity_by_id(user_id)

            if not user_login or TimeHelper.format_time_to_datetime(user_login.ExpireTime) < TimeHelper.get_now_datetime():
                if not is_need_login:
                    return invoke_result
                self.clear_user_cookie()
                invoke_result.ResultCode = "login_expire"
                invoke_result.ResultMessage = "用户已过期，请重新登录"
                return invoke_result
            if user_login.UserToken != user_token:
                if not is_need_login:
                    return invoke_result
                self.clear_user_cookie()
                invoke_result.ResultCode = "login_expire"
                invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
                return invoke_result

            curr_user_info = UserInfoModel(manage_context_key).get_entity_by_id(user_id)
            if not curr_user_info:
                invoke_result.ResultCode = "login_expire"
                invoke_result.ResultMessage = "用户已过期，请重新登录"
                return invoke_result
            if curr_user_info.IsLock == 1:
                invoke_result.ResultCode = "login_expire"
                invoke_result.ResultMessage = "用户已被锁，请联系管理员"
                return invoke_result

            if base_manage_context_key != manage_context_key:
                curr_user_info = UserInfoModel(base_manage_context_key).get_entity_by_id(user_id)
                if not curr_user_info:
                    invoke_result.ResultCode = "login_expire"
                    invoke_result.ResultMessage = "用户已过期，请重新登录"
                    return invoke_result
                if curr_user_info.IsLock == 1:
                    invoke_result.ResultCode = "login_expire"
                    invoke_result.ResultMessage = "用户已被锁，请联系管理员"
                    return invoke_result

            user_login.ExpireTime = TimeHelper.add_hours_by_format_time(hour=config.get_value("login_expire", 10))
            user_login_model.update_table(f"ExpireTime='{user_login.ExpireTime}'", "UserID=%s", user_login.UserID)

        return invoke_result

    def login_filter(self, is_need_login, optional_params):
        """
        :description: 登录过滤器
        :param is_need_login: 是否需要登录（true需要false不需要）
        :param optional_params: 其他参数
        :return: InvokeResult
        """
        invoke_result = InvokeResult()

        if not is_need_login:
            return invoke_result

        # 获取头部信息
        header_token = self.request_header_token()
        user_id = header_token["UserID"] if header_token.__contains__("UserID") else ""
        user_token = header_token["UserToken"] if header_token.__contains__("UserToken") else ""
        user_id_md5 = header_token["UserIDMD5"] if header_token.__contains__("UserIDMD5") else ""
        if user_id.strip() == "" or user_token.strip() == "" or user_id_md5.strip() == "":
            invoke_result.ResultCode = "error"
            invoke_result.ResultMessage = "操作失败，用户未登录"
            return invoke_result
        if CryptoHelper.md5_encrypt(user_id, config.get_value("login_encrypt_key", "7C34A5212F7845CB85D4BBB589502D9B")) != user_id_md5:
            invoke_result.ResultCode = "error"
            invoke_result.ResultMessage = "操作失败，用户未登录"
            return invoke_result

        invoke_result = self.check_login_user(user_id, user_token, is_need_login)

        return invoke_result

    def power_filter(self, is_check_power, optional_params):
        """
        :description: 权限过滤器
        :param is_check_power: 是否需要验证权限（true需要false不需要）
        :param optional_params: 其他参数
        :return: InvokeResult
        """
        invoke_result = InvokeResult()
        user_info = self.get_curr_user_info()
        base_user_info = self.get_base_user_info()
        if not user_info or not base_user_info:
            invoke_result.ResultCode = "login_expire"
            invoke_result.ResultMessage = "用户已过期，请重新登录"
            return invoke_result
        if is_check_power and user_info.IsSuper != 1 and base_user_info.IsSuper != 1:
            api_path = self.request.path
            if api_path.strip() == "":
                invoke_result.ResultCode = "error"
                invoke_result.ResultMessage = "该用户没有权限，请联系管理员"
                return invoke_result
            page_id = self.request_manage_page_id()
            cote_id = page_id.split("$")[1] if page_id.__contains__("$") else ""
            if not self.check_power_menu(api_path, cote_id):
                invoke_result.ResultCode = "error"
                invoke_result.ResultMessage = "该用户没有权限，请联系管理员"
                return invoke_result
        return invoke_result
    
    def check_password_strength(self, password):
        """
        :description: 检查密码强度
        :param password: 密码字符串
        :return 符合强度=True,message 不符合密码强度=False,message
        :last_editors: ChenXiaolei
        """
        message = "密码必须至少包含8个字符、至少包含一个数字、字母。"
        password_len = len(password)

        if password_len<8:
            return False,message

        n1=0
        n2=0
        n3=0
        for i in range(password_len):
            ch=password[i]
            if "0"<=ch<="9":
                n1=1
            elif "a"<=ch<="z"or "A"<=ch<="Z":
                n2=1
            else:
                n3=1
        x=n1+n2+n3
        return (False, message) if x<2 else (True, str(x))


def login_filter(is_need_login=True, optional_params=None):
    """
    :description: 登陆过滤装饰器 仅限handler使用
    :param is_need_login：是否需要登陆（true需要false不需要）
    :param optional_params：其他参数
    :return: handler
    """
    def check_login(handler):
        def wrapper(self, **args):
            invoke_result = self.login_filter(is_need_login, optional_params)
            if invoke_result.ResultCode != "0":
                return self.response_common(invoke_result.ResultCode, invoke_result.ResultMessage)
            return handler(self, **args)

        return wrapper

    return check_login


def power_filter(is_check_power=True, optional_params=None):
    """ 
    :description: 权限过滤装饰器 仅限handler使用
    :param is_check_power: 是否需要验证权限（true需要false不需要）
    :param optional_params: 其他参数
    :return: handler
    """
    def check_power(handler):
        def wrapper(self, **args):
            invoke_result = self.power_filter(is_check_power, optional_params)
            if invoke_result.ResultCode != "0":
                return self.response_common(invoke_result.ResultCode, invoke_result.ResultMessage)

            return handler(self, **args)

        return wrapper

    return check_power


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-29 10:02:31
:LastEditTime: 2020-12-10 10:59:20
:LastEditors: ChenXiaolei
:Description: 金山云存储
"""
import base64
from enum import Enum
from seven_framework.log import  *
from seven_framework.uuid import *
from seven_framework.file import KS3Helper

from seven_studio.utils.random import *

from seven_studio.models.seven_model import InvokeResult
from seven_studio.models.seven_model import FileUploadInfo


class HostEnum(Enum):
    """
    :description: 服务地址
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 中国（北京）
    BeiJing = "ks3-cn-beijing.ksyun.com"
    # 中国（上海）
    ShangHai = "ks3-cn-shanghai.ksyun.com"
    # 中国（香港）
    XiangGang = "ks3-cn-hk-1.ksyun.com"


class PolicyEnum(Enum):
    """
    :description: 策略
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    PublicReadWrite = "public-read-write"
    PublicRead = "public-read"
    Private = "private"


class StorageClassEnum(Enum):
    """
    :description: 存储方式
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 标准存储
    STANDARD = "STANDARD"
    # 低频存储
    STANDARD_IA = "STANDARD_IA"


class KS3:
    """
    :description: 
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    logger_error = Logger.get_logger_by_name("log_error")
    logger_info = Logger.get_logger_by_name("log_info")

    @classmethod
    def upload(self, storage_config, file_name='', stream=None, file_path=''):
        """
        :description: 文件上传
        :param storage_config：配置内容
        :param file_name：文件名(按路径上传时此参数为空)
        :param stream：文件内容(按路径上传时此参数为空)
        :param file_path：文件路径(为空按stream上传，不为空则按路径上传)
        :return: InvokeResult
        :last_editors: HuangJingCan
        """
        # ks3 = KS3Helper("AKLT89aOKN-3TSKCO_3wajfFBw", "OE1s4w3nEq4tXSMd0WilcWhf4JgcxIYnA5XAvY24jQUXdj48ARYNs/oP5XNQtHc9hw==", "ks3-cn-beijing.ksyun.com")
        # ks3.put_file_from_file_path("gao7ts", "IMG_8726.HEIC", "/Users/chenxiaolei/Downloads/IMG_8726.HEIC")

        invoke_result = InvokeResult()
        file_upload_info = FileUploadInfo()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        domain = file_upload_config.get("Domain", "").rstrip('/')
        is_autofile_name = file_upload_config.get("IsAutoFileName", 0)
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        # 返回文件名
        file_name = os.path.basename(file_path) if file_path != "" else file_name

        if is_autofile_name == 1:
            file_extension = os.path.splitext(file_name)[1]
            file_name = UUIDHelper.get_uuid().replace("-", "") + file_extension

        try:
            # conn = Connection(access_key, secret_key, end_point, is_secure=False, domain_mode=False)
            # b = conn.get_bucket(bucket).new_key(folder + file_name)
            conn = KS3Helper(access_key, secret_key, end_point)
            key_name = folder + file_name
            result = False
            if file_path != "":
                # ret = b.set_contents_from_filename(file_path, policy=PolicyEnum.PublicRead.value)
                result = conn.put_file_from_file_path(bucket, key_name, file_path, PolicyEnum.PublicRead.value)
            else:
                # ret = b.set_contents_from_string(stream, policy=PolicyEnum.PublicRead.value)
                result = conn.put_file_from_contents(bucket, key_name, stream, PolicyEnum.PublicRead.value)

            if result:
                virtual_name = RandomUtil.get_random_switch_string(domain).rstrip('/')
                file_upload_info.ResourcePath = virtual_name + "/" + key_name
                invoke_result.Data = file_upload_info.__dict__
        except Exception as ex:
            self.logger_error.exception(ex)
            invoke_result.ResultCode = "1"
            invoke_result.ResultMessage = "KS3上传文件出错"

        return invoke_result

    @classmethod
    def delete(self, storage_config, file_path):
        """
        :description: 删除文件
        :param storage_config：配置内容
        :param file_path：文件路径
        :return:
        :last_editors: HuangJingCan
        """

        if file_path=="":
            return 1
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        # 返回文件名
        file_name = os.path.basename(file_path) if file_path != "" else ""

        result = 0

        try:
            # conn = Connection(access_key, secret_key, end_point, is_secure=False, domain_mode=False)
            # b = conn.get_bucket(bucket)
            # b.delete_key(folder + file_name)
            conn = KS3Helper(access_key, secret_key, end_point)
            conn.del_file(bucket, folder + file_name)
            result = 1
        except Exception as ex:
            self.logger_error.exception(ex)

        return result

    @classmethod
    def get(self, storage_config, file_path):
        """
        :description: 获取文件
        :param storage_config：配置内容
        :param file_path：文件路径或者文件名
        :return: 文件流
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        # 返回文件名
        file_name = os.path.basename(file_path) if file_path != "" else ""

        result = ""

        try:
            # conn = Connection(access_key, secret_key, end_point, is_secure=False, domain_mode=False)
            # b = conn.get_bucket(bucket)
            # k = b.get_key(folder + file_name)
            # if k:
            #     result = k.get_contents_as_string()
            conn = KS3Helper(access_key, secret_key, end_point)
            result = conn.get_file_contents(bucket, folder + file_name)
        except Exception as ex:
            self.logger_error.exception(ex)

        return result

    @classmethod
    def get_list(self, storage_config, prefix=""):
        """
        :description: 列举Bucket内的文件或者目录
        :param storage_config：配置内容
        :param file_path：文件路径
        :param prefix：指定前缀
        :return: 文件列表，目录列表
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        result_list = []
        result_dir = []

        try:
            conn = KS3Helper(access_key, secret_key, end_point)
            result_list, result_dir = conn.get_bucket_objects(bucket, prefix)
        except Exception as ex:
            self.logger_error.exception(ex)

        return result_list, result_dir

    @classmethod
    def upload_part(self, storage_config, source_path):
        """
        :description: 分块上传-单线程
        :param storage_config：配置内容
        :param source_path：文件路径
        :param prefix：指定前缀
        :return: 文件列表，目录列表
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()
        file_upload_info = FileUploadInfo()
        file_upload_config = json.loads(storage_config)

        access_key = file_upload_config.get("AccessKey", "")
        secret_key = file_upload_config.get("SecretKey", "")
        bucket = file_upload_config.get("Bucket", "")
        end_point = file_upload_config.get("EndPoint", "")
        domain = file_upload_config.get("Domain", "").rstrip('/')
        is_autofile_name = file_upload_config.get("IsAutoFileName", 0)
        folder = file_upload_config.get("Folder", "").strip('/')
        folder = folder + "/" if folder != "" else folder

        file_name = ""
        # 返回文件名
        file_name = os.path.basename(source_path) if source_path != "" else file_name

        if is_autofile_name == 1:
            file_extension = os.path.splitext(file_name)[1]
            file_name = UUIDHelper.get_uuid().replace("-", "") + file_extension

        try:
            conn = KS3Helper(access_key, secret_key, end_point)
            conn.multi_put_file(bucket, folder + file_name, source_path)

            virtual_name = RandomUtil.get_random_switch_string(domain).rstrip('/')
            file_upload_info.ResourcePath = virtual_name + "/" + folder + file_name
            invoke_result.Data = file_upload_info.__dict__

        except Exception as ex:
            self.logger_error.exception(ex)
            invoke_result.ResultCode = "1"
            invoke_result.ResultMessage = "KS3上传文件出错"

        return invoke_result

    @classmethod
    def water_marker_text(self, img_url, text, font="", fontsize="", fill="", dissolve="", gravity="", dx="", dy="", q=""):
        """
        :description: 文字水印
        :param img_url：文件路径
        :param text：必填；水印文字(base64EncodeText,经过URL安全的Base64编码)
        :param font：文字水印字体(base64EncodeFont，经过URL安全的Base64编码)。默认为黑体
        :param fontsize：字体大小(整形)，单位为缇(1缇=1/20磅),默认值500
        :param fill：文字水印颜色(base64EncodeFill,经过URL安全的Base64编码)，可以是RGB格式，也可以是颜色名称(例如 black),还可以是十六进制(例如 ## FF0000),可以参考RGB对照表
        :param dissolve：不透明度。取值范围为1~100，默认值为100。100为完全不透明。
        :param gravity：水印位置。可参考下面的水印锚点参数表，默认为SouthEast(右下方)。
                        NorthWest	North	NorthEast
                        West	    Center	East
                        SouthWest	South	SouthEast
        :param dx：横轴(x轴)边距，单位为像素(px),默认值为10
        :param dy：纵轴(y轴)边距，单位为像素(px),默认值为10
        :param q：决定 jpg 图片的相对quality,对原图压缩。范围为0-100 , 0表示高压缩低质量，100表示低压缩，高质量。默认90
        :return: 图片地址
        :last_editors: HuangJingCan
        """
        text = base64.b64encode(text.encode("utf-8")).decode('utf-8')
        if font != "":
            font = base64.b64encode(font.encode("utf-8")).decode('utf-8')
            font = f"&font={font}"
        if fontsize != "": fontsize = f"&fontsize={fontsize}"
        if fill != "": fill = f"&fill={fill}"
        if dissolve != "": dissolve = f"&dissolve={dissolve}"
        if gravity != "": gravity = f"&gravity={gravity}"
        if dx != "": dx = f"&dx={dx}"
        if dy != "": dy = f"&dy={dy}"
        if q != "": q = f"&q={q}"

        return f"{img_url}@base@tag=imgWaterMarker&type=2&text={text}{font}{fontsize}{fill}{dissolve}{gravity}{dx}{dy}{q}"

    @classmethod
    def water_marker_img(self, img_url, image, wtw="", wth="", dissolve="", gravity="", dx="", dy="", q=""):
        """
        :description: 图片水印
        :param img_url：文件路径
        :param image：必填；水印源图片网址(base64EncodeImageURI,经过URL安全的Base64编码),必须保证此网址返回一张图片
        :param wtw：水印添加宽度阈值，小于该值将不进行图片水印操作，单位为像素(px)。范围为0以上的整数
        :param wth：水印添加高度阈值，小于该值将不进行图片水印操作，单位为像素(px)。范围为0以上的整数
        :param dissolve：不透明度。取值范围为1~100，默认值为100。100为完全不透明。
        :param gravity：水印位置。可参考下面的水印锚点参数表，默认为SouthEast(右下方)。
                        NorthWest	North	NorthEast
                        West	    Center	East
                        SouthWest	South	SouthEast
        :param dx：横轴(x轴)边距，单位为像素(px),默认值为10
        :param dy：纵轴(y轴)边距，单位为像素(px),默认值为10
        :param q：决定 jpg 图片的相对quality,对原图压缩。范围为0-100 , 0表示高压缩低质量，100表示低压缩，高质量。默认90
        :return: 图片地址
        :last_editors: HuangJingCan
        """
        image = base64.b64encode(image.encode("utf-8")).decode('utf-8')
        if wtw != "": wtw = f"&wtw={wtw}"
        if wth != "": wth = f"&wth={wth}"
        if dissolve != "": dissolve = f"&dissolve={dissolve}"
        if gravity != "": gravity = f"&gravity={gravity}"
        if dx != "": dx = f"&dx={dx}"
        if dy != "": dy = f"&dy={dy}"
        if q != "": q = f"&q={q}"

        return f"{img_url}@base@tag=imgWaterMarker&type=1&image={image}{wtw}{wth}{dissolve}{gravity}{dx}{dy}{q}"

    @classmethod
    def img_scale(self, img_url, w="", h="", m="", p="", so="", q="", F="", r="", c="", f="", s="", cox="", coy="", rotate="", et="", etw="", eth="", etc=""):
        """
        :description: 图片处理（缩放/裁剪/旋转/格式转换）
        :param img_url：图片地址
        :param m：<mode>缩略模式，0-长边优先缩放，缩放按照较长边的缩放比例进行缩放，不剪裁，1-短边优先缩放，缩放按照较短边的缩放比例进行缩放，不剪裁，2-限定缩略图的宽最少为<width>，高最少为<height>，进行等比缩放
        :param w：<width>缩略宽度/裁剪宽度，w/h必须有一个；取值范围：1-4096；指定目标缩略图的宽度,单位:像素(px)。 当单独使用时,代表按照宽度等比缩放。
        :param h：<height>缩略高度/裁剪高度，w/h必须有一个；取值范围：1-4096；指定目标缩略图的高度,单位:像素(px)。 当单独使用时,代表按照高度等比缩放。
        :param p：<p>图片按比例缩放;倍数百分比。取值范围：1-1000;小于 100，即是缩小，大于 100 即是放大，放大时p值取值范围如下：图片小于等于1MB时，最大支持放大到10倍；图片大于1MB且小于2MB，最大支持放大5倍，图片大于2MB，最大支持放大3倍图片长边像素值*倍数最大支持5000
        :param so: <so>图片放大；指定为放大模式；值为1时开启图片放大
        :param q: <quality>决定 jpg 图片的相对quality,对原图压缩，范围为0-100 , 0表示高压缩低质量,100表示低压缩，高质量。默认q=75。
        :param F: <format>指定目标缩略图的输出格式，默认按照原图格式输出。输出格式支持JPG、JPEG、PNG、GIF、WBMP、BMP、WEBP。
        :param r: <auto-orient>有些相机拍的照片会出现旋转,本参数就是否根据原图 EXIF 信息自动适应方向，默认值r=0 r=0:按原图默认处理 r = 1:按原图 EXIF 信息自动旋转图片 r = 2:自定义旋转角度，旋转角度由<rotate> 参数指定
        :param c: <cut>是否裁剪,默认值是:0(否)对缩放后超出范围的图片内容进行剪裁,这种情况一般发生在按照短边优先的等比缩放中。缩放会以图片中线为中心,进行上下/左右的 裁剪,得到相应的尺寸
        :param f: <fixed>是否固定宽高,默认值f=0(否)f=1:以图片中线为中心,裁剪指定w和h的区域,此参数与参数 cut 配合使用,当使用 f 时会固定图片的宽高,进行非缩放裁剪
        :param s: <strip>是否支持去除元数据。默认值1，0表示否，1表示是
        :param cox: <x-coordinate>裁剪起始横坐标，此参数与参数cut及参数fixed配合使用，当不设置裁剪起始横坐标时则默认居中裁剪
        :param coy: <y-coordinate>裁剪起始纵坐标，此参数与参数cut及参数fixed配合使用，当不设置裁剪起始纵坐标时则默认居中裁剪
        :param rotate: <degree>旋转角度,取值范围1-360,缺省为不旋转。自定义旋转角度需指定参数<r>等于2
        :param et: <extent>是否增加背景，默认值是0（否）。对缩放后空白范围的图片内容进行背景填充。
        :param etw: <extent width>指定背景宽度，单位：像素（px），默认值是原图最大宽度（若eth与etw均没有设置，则默认取原图高度和宽度的最大值，构成正方形；若只设置etw，则高度默认为原图高度）。取值范围：1-4096
        :param eth: <extent height>指定背景高度，单位：像素（px），默认值是原图最大高度（若eth与etw均没有设置，则默认取原图高度和宽度的最大值，构成正方形；若只设置eth，则宽度默认为原图宽度）。取值范围：1-4096
        :param etc: <extent colour>指定背景颜色，支持RRGGBB格式，默认值是FFFFFF（透明色为“transparent”，透明背景色支持图片格式为PNG、GIF）。
        :return: 图片地址
        :last_editors: HuangJingCan
        """
        if w != "": w = f"&w={w}"
        if h != "": h = f"&h={h}"
        if m != "": m = f"&m={m}"
        if p != "": p = f"&p={p}"
        if so != "": so = f"&so={so}"
        if q != "": q = f"&q={q}"
        if F != "": F = f"&F={F}"
        if r != "": r = f"&r={r}"
        if c != "": c = f"&c={c}"
        if f != "": f = f"&f={f}"
        if s != "": s = f"&s={s}"
        if cox != "": cox = f"&cox={cox}"
        if coy != "": coy = f"&coy={coy}"
        if rotate != "": rotate = f"&rotate={rotate}"
        if et != "": et = f"&et={et}"
        if etw != "": etw = f"&etw={etw}"
        if eth != "": eth = f"&eth={eth}"
        if etc != "": etc = f"&etc={etc}"

        return f"{img_url}@base@tag=imgScale{w}{h}{m}{p}{so}{q}{F}{r}{c}{f}{s}{cox}{coy}{rotate}{et}{etw}{eth}{etc}"


"""
:Author: HuangJingCan
:Date: 2020-03-24 19:48:05
:LastEditTime: 2020-04-15 10:08:00
:LastEditors: HuangJingCan
:Description: 角色权限扩展类
"""
from seven_studio.models.db_models.role.role_power_model import *


class RolePowerEx(RolePower):
    def get_list_by_role_power_list(self, role_power_list):
        for role_power in role_power_list:
            role_power = self.get_entity_by_role_power(role_power)
        return role_power_list

    def get_entity_by_role_power(self, role_power):
        role_power.MenuCoteID = role_power.MenuID + "$" + role_power.CoteID if role_power.CoteID.strip() != "" else role_power.MenuID
        return role_power


class RolePowerModelEx(RolePowerModel):
    def get_role_power_list(self, rowid_list):
        if not rowid_list or len(rowid_list) == 0:
            return []
        rowid_list_str = str(rowid_list).strip('[').strip(']')
        return self.get_list(f"RoleID IN({rowid_list_str})")